#
# spec file for package xpra
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%ifarch x86_64 ppc64 s390x aarch64 riscv64
%global with_pandoc 1
%endif
%bcond_with pandoc
# -----
# Comes from git tarball setup.py:
# setup.py build --verbose ...
# Xpra version 4.4
#%%define xpra_ver 4.4
%define xpra_ver 5.0
# ----
%if 0%{?suse_version} >= 1550
%define ffmpeg_ver 5
%else
%define ffmpeg_ver 4
%endif

# ----
%global __requires_exclude ^typelib\\(GtkosxApplication\\)|typelib\\(GdkGLExt\\)|typelib\\(GtkGLExt\\).*$
Name:           xpra
Version:        5.0+git20221127.3e61ef1c
Release:        lp156.2.2
Summary:        Remote display server for applications and desktops
License:        BSD-3-Clause AND GPL-2.0-or-later AND LGPL-3.0-or-later AND MIT
Group:          System/X11/Utilities
URL:            https://www.xpra.org/
Source0:        %{name}-%{version}.tar.gz
Source1:        xpra-icon.png
# ----
BuildRequires:  ImageMagick
BuildRequires:  brotli
BuildRequires:  cups
BuildRequires:  cups-devel
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  ffmpeg-%{ffmpeg_ver}
BuildRequires:  ffmpeg-%{ffmpeg_ver}-libavcodec-devel
BuildRequires:  ffmpeg-%{ffmpeg_ver}-libavformat-devel
BuildRequires:  ffmpeg-%{ffmpeg_ver}-libavutil-devel
BuildRequires:  ffmpeg-%{ffmpeg_ver}-libswresample-devel
BuildRequires:  ffmpeg-%{ffmpeg_ver}-libswscale-devel
BuildRequires:  git-core
BuildRequires:  hicolor-icon-theme
# ----
%if 0%{?suse_version} >= 1550
%define using_release "distribution-release"
BuildRequires:  distribution-release
%else
%define using_release "openSUSE-release"
BuildRequires:  openSUSE-release
%endif
# ----
BuildRequires:  pam-devel
%if %{with pandoc}
BuildRequires:  pandoc
%endif
BuildRequires:  pkgconfig
BuildRequires:  python3-Cython >= 0.20.0
BuildRequires:  python3-devel
BuildRequires:  python3-gobject-devel
BuildRequires:  python3-pyxdg
BuildRequires:  python3-setuptools
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libavcodec) >= 58
BuildRequires:  pkgconfig(libavformat) >= 58
BuildRequires:  pkgconfig(liblz4)
BuildRequires:  pkgconfig(libswscale) >= 5
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(libwebp) >= 0.4
# TW can do this, 15.4 can't ...
#BuildRequires:  pkgconfig(pam)
#BuildRequires:  pkgconfig(pam_misc)
BuildRequires:  pkgconfig(py3cairo)
BuildRequires:  procps-devel
BuildRequires:  qrencode-devel
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(vpx) >= 1.4.0
BuildRequires:  pkgconfig(xcomposite)
BuildRequires:  pkgconfig(xdamage)
BuildRequires:  pkgconfig(xkbfile)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(xres)
BuildRequires:  pkgconfig(xtst)
Requires:       dbus-1-x11
Requires:       gstreamer-plugins-base
Requires:       gstreamer-plugins-good
Requires:       gstreamer-utils
%if 0%{?sle_version} && 0%{?sle_version} < 150300
Requires:       pulseaudio
%else
Requires:       pulseaudio-daemon
%endif
Requires:       pulseaudio-utils
Requires:       python3-Pillow
Requires:       python3-cairo
Requires:       python3-dbus-python
Requires:       python3-gobject-Gdk
Requires:       python3-gst
Requires:       python3-lz4
Requires:       python3-opencv
Requires:       python3-pycups
Requires:       python3-rencode
Requires:       shared-mime-info
Requires:       xf86-video-dummy
Requires:       xorg-x11-xauth
Requires(post): %fillup_prereq
Recommends:     lsb-release
Recommends:     pinentry
Recommends:     pulseaudio-module-x11
Recommends:     python3-dnspython
Recommends:     python3-netifaces
Recommends:     python3-opencv
Recommends:     python3-opengl
Recommends:     python3-opengl-accelerate
Recommends:     python3-paramiko
Recommends:     python3-pyinotify
Recommends:     python3-pyxdg
Recommends:     xdg-menu
# Overflow errors on 32-bit
ExcludeArch:    %ix86
%{?systemd_ordering}

%description
Xpra is "screen for X": it allows you to run X programs, usually on a remote
host, direct their display to your local machine, and then to disconnect from
these programs and reconnect from the same or another machine, without losing
any state. It gives you remote access to individual applications.

Xpra is "rootless" or "seamless": programs you run under it show up on your
desktop as regular programs, managed by your regular window manager.
Sessions can be accessed over SSH, or password protected over plain TCP sockets.
Xpra is usable over reasonably slow links and does its best to adapt to changing
network bandwidth constraints.

%prep

%setup -q
find -name '*.py' \
  -exec sed -i '1{\@^#!/usr/bin/env python@d}' {} +
install -m0644 %{SOURCE1} -T fs/share/icons/xpra.png
# misc fixes for SUSE specific differences upstream
baselibexec=$(basename $(rpm -E '%{_libexecdir}'))
sed -e 's|__FILLUPDIR__|%{_fillupdir}|' \
  -e 's|__UNITDIR__|%{_unitdir}|' \
  -e 's|share/doc/xpra|share/doc/packages/xpra|' \
  -e "s|__LIBEXECDIR__|$baselibexec|" \
  -i setup.py

%build

### DEBUGGING
echo "ffmpeg_ver:    %ffmpeg_ver"
echo "sle_version:   %sle_version"
echo "suse_version:  %suse_version"
echo "using_release: %using_release"
#####

export CFLAGS="%{optflags}"
#%%if 0%%{?suse_version} <= 1500
export CFLAGS="$CFLAGS -Wno-error=deprecated-declarations"
#%%endif
python3 setup.py clean

python3 setup.py build \
  --verbose \
  --with-enc_ffmpeg \
  --with-vpx \
  --with-dec_avcodec2 \
  --with-csc_swscale \
  --with-webp \
  --with-Xdummy \
  --with-Xdummy_wrapper \
  --with-opengl \
  --with-service \
  --without-cuda_kernels \
  --without-nvenc \
%if !%{with pandoc}
  --without-docs \
%endif
  --without-nvfbc
#%%if %%{ffmpeg_ver} == 4
#  --without-nvfbc
#%%endif
#%%if %%{ffmpeg_ver} == 5
#  --without-nvfbc
#%%endif
#%%if %%{ffmpeg_ver} == 5
#  --without-nvfbc \
#  --without-strict
#%%endif

%install
python3 setup.py install \
  --skip-build \
  --root %{buildroot} \
  --prefix %{_prefix} \
  --with-service \
  --with-Xdummy \
  --with-Xdummy_wrapper \
%if !%{with pandoc}
  --without-docs \
%endif
  --verbose

rm -rf %{buildroot}%{_datadir}/xpra/cuda

%suse_update_desktop_file -r xpra Network RemoteAccess
%suse_update_desktop_file -r xpra-gui Network RemoteAccess
%suse_update_desktop_file -r xpra-launcher Network RemoteAccess

mkdir -pv %{buildroot}%{_sbindir}
ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}

%if 0%{?suse_version} > 1500
mkdir -p %{buildroot}%{_pam_vendordir}
mv %{buildroot}%{_sysconfdir}/pam.d/xpra %{buildroot}%{_pam_vendordir}
%endif

%fdupes -s %{buildroot}

%pre
getent group xpra >/dev/null || groupadd -r xpra
mkdir -p %{_rundir}/%{name} || exit 1
%service_add_pre %{name}.service
%service_add_pre %{name}.socket
%if 0%{?suse_version} > 1500
# Prepare for migration to /usr/lib; save any old .rpmsave
for i in pam.d/xpra ; do
     test -f %{_sysconfdir}/${i}.rpmsave && mv -v %{_sysconfdir}/${i}.rpmsave %{_sysconfdir}/${i}.rpmsave.old ||:
done

%posttrans
# Migration to /usr/lib, restore just created .rpmsave
for i in pam.d/xpra ; do
     test -f %{_sysconfdir}/${i}.rpmsave && mv -v %{_sysconfdir}/${i}.rpmsave %{_sysconfdir}/${i} ||:
done
%endif

%post
%service_add_post %{name}.service
%service_add_post %{name}.socket
%fillup_only %{name}
%tmpfiles_create %{_tmpfilesdir}/xpra.conf

%preun
%service_del_preun %{name}.service
%service_del_preun %{name}.socket

%postun
%service_del_postun %{name}.service
%service_del_postun %{name}.socket

%files
%doc docs/README.md docs/CHANGELOG.md
%if %{with pandoc}
%doc %{_defaultdocdir}/xpra
%endif
%license COPYING
%dir %{_datadir}/xpra
%dir %{_sysconfdir}/xpra
%dir %{_sysconfdir}/xpra/conf.d
%dir %{_sysconfdir}/xpra/content-categories
%dir %{_sysconfdir}/xpra/content-parent
%dir %{_sysconfdir}/xpra/content-type
%dir %{_sysconfdir}/xpra/http-headers
%if 0%{?suse_version} > 1500
%{_pam_vendordir}/xpra
%else
%dir %{_sysconfdir}/pam.d
%config(noreplace) %{_sysconfdir}/pam.d/xpra
%endif
%config(noreplace) %{_sysconfdir}/dbus-1/system.d/xpra.conf
%config(noreplace) %{_sysconfdir}/xpra/*.conf
%config(noreplace) %{_sysconfdir}/xpra/conf.d/*.conf
%config(noreplace) %{_sysconfdir}/xpra/content-categories/*.conf
%config(noreplace) %{_sysconfdir}/xpra/content-parent/*.conf
%config(noreplace) %{_sysconfdir}/xpra/content-type/*.conf
%config(noreplace) %{_sysconfdir}/xpra/http-headers/*.txt
%config(noreplace) %{_sysconfdir}/X11/xorg.conf.d/90-xpra-virtual.conf
%{_fillupdir}/sysconfig.%{name}
%{_bindir}/run_scaled
%{_bindir}/xpra
%{_bindir}/xpra_Xdummy
%{_bindir}/xpra_launcher
%{_udevrulesdir}/71-xpra-virtual-pointer.rules
%dir %{_libexecdir}/xpra
%{_libexecdir}/xpra/auth_dialog
%{_libexecdir}/xpra/gnome-open
%{_libexecdir}/xpra/gvfs-open
%{_libexecdir}/xpra/xdg-open
%{_libexecdir}/xpra/xpra_signal_listener
%{_libexecdir}/xpra/xpra_udev_product_version
%{_sbindir}/rc%{name}
%{python3_sitearch}/xpra
%{python3_sitearch}/%{name}-%{xpra_ver}-py%{python3_version}.egg-info
%{_datadir}/applications/xpra-gui.desktop
%{_datadir}/applications/xpra-launcher.desktop
%{_datadir}/applications/xpra-shadow.desktop
%{_datadir}/applications/xpra.desktop
%{_datadir}/metainfo/xpra.appdata.xml
%{_datadir}/pixmaps/xpra-mdns.png
%{_datadir}/pixmaps/xpra-shadow.png
%{_datadir}/pixmaps/xpra.png
%{_datadir}/mime/packages/application-x-xpraconfig.xml
%{_datadir}/xpra/autostart.desktop
%{_datadir}/xpra/bell.wav
%{_datadir}/xpra/css
%{_datadir}/xpra/icons
%{_prefix}/lib/cups/backend/xpraforwarder
%{_mandir}/man1/run_scaled.1%{?ext_man}
%{_mandir}/man1/xpra.1%{?ext_man}
%{_mandir}/man1/xpra_launcher.1%{?ext_man}
%{_sysusersdir}/xpra.conf
%{_tmpfilesdir}/xpra.conf
%{_unitdir}/xpra.service
%{_unitdir}/xpra.socket
%ghost %dir %{_rundir}/xpra
%ghost %dir %{_rundir}/xpra/proxy

%changelog
* Mon Jan 16 2023 Stefan Schubert <schubi@suse.com>
- Migration of PAM settings to /usr/lib/pam.d.
* Tue Nov 29 2022 scott.bradnick@suse.com
- Update to version v5.0+git20221127.3e61ef1c:
  * use the correct value for bits-per-pixel with alpha
  * prefer BGRA to RGBA
  * add scaling debug logging
  * f-stringify
  * fix avif encoder loading
  * output using the same colorspace used for encoding
  * missing fake attributes for opengl toolbox test
  * #3374 spng uses unpremultiplied alpha
  * preserve ':' prefix for X11 displays
  * #3692 re-add display to ssh args
  * add debug logging
  * #3692 ssh config overrides url
  * fix minor pylint warnings
  * more helpful messages
  * fix minor pylint warnings
  * use premultiplied alpha with pillow
  * fix minor warnings
  * #3359 don't use odd heights for vertically subsampled formats
  * remove debug logging
  * support specifying the key file password
  * #3504 make it possible to bypass the check
  * minor warnings
  * #3504 nvjpeg decoder no longer leaks memory with latest drivers
  * silence minor pylint warnings
  * more helpful warning when there is no pixel data
  * fix memoryview TypeError on MS Windows with lz4 raw cursor data
  * try to continue without a cuda context
  * oops: another pass missed
  * find link.exe path with newer versions of VS
  * make sure to include cuda libs when needed
  * avoid pycuda import warnings on win32
  * f-stringify
  * also need innosetup to generate EXE, MSIWrapper for MSI
  * handle more invalid x264 version strings
  * hint for spng
  * add missing import
  * fix compatibility with older versions of cryptography
  * fix minor warnings
  * more python deps, add verpatch link
  * #2743 don't enable local sockets by default on win32
  * path missed during refactoring
  * silence pylint warning
  * try VS 2022 Community path
  * switch to cuda 11.8
  * don't show '64-bit' which is the default
  * try to install more indirect dependencies
  * simplify: install for $MSYSTEM_ARCH
  * also install pyopengl-accelerate via MSYS2
  * pycuda 2022.2 can be built on Fedora 37
  * pycuda 2022.2
  * #3690 uinput packages can be broken in new ways
  * #3376 expose quic config object
  * #3376 expose quic transport info in our connection's scope attribute
  * #3376 minor tweaks and expose more info
  * add quic link
  * add quic link
  * seamless is X11 only
  * try harder to get a meaningful connection error message
  * exceptions are re-thrown, no need to log them at 'error' level here
  * f-stringify
  * better diagnostic messages when quic components are missing
  * failures to connect should not leave the splash screen hanging
  * remove unused arguments
  * f-stringify
  * better log messages
  * cosmetic
  * add spng
  * the key is not a secret
  * #3376 honour the request path part of the URL
  * #3376 add webtransport stub + refactoring
  * unused import
  * #3685 clamp clock values to 'unsigned long'
  * cosmetic logging tweaks
  * #3376 uvloop is not available on win32
  * #3376 cleanups and explicit IPv6 support
  * #3376 simplify: create the UDP socket ourselves
  * move uvloop recommendation to aioquic
  * support functions that return exceptions
  * #3376 install aioquic via pip for now
  * #3376 we no longer need wsproto
  * missed from ff04ad48e3ec7a894c091a27c5b7cdf0e9374fec
  * no more csc_* modules matching without csc_cython
  * #3376 add working client connection
  * make websocket close packet into a reusable function
  * log and re-throw errors calling async functions
  * #3376 simplify
  * #3376 hook up the server connection
  * make it easier to re-use opcodes
  * avoid errors when cleaning up
  * cosmetic
  * #3376 remove dependency on wsproto
  * flush_then_close improvements
  * cosmetic
  * provide utility function for waiting for async calls
  * remove debug logging
  * use ellipsizer to reduce debug logging
  * #3376 make uvloop optional, always wait for main loop
  * missed from 562b1f184792643b6364832b7b4a9d4df93a53e5
  * #3376 split handlers to separate files
  * cosmetic
  * use ValueError for validation
  * cython mask module should be safe to import globally
  * clarify test failures
  * oops: missing delayed imports
  * older versions of python-cryptography require the backend argument
  * prevent circular import
  * prevent circular import
  * missed from refactoring of header module in 3b68b9f34679b38d8b7f35a541c694af64f7a10d
  * check for main loop after waiting
  * move xpra's protocol modules to a subdir
  * all modules need an __init__ file
  * test code does not belong in releases
  * only one backend is supported: python-cryptography
  * remove unused constant, expose non-backend info
  * oops: match refactoring in b2d0b2fb5e87bcae631a32a80b2d261e7b07d130
  * adjust tests for 1492a2210504d9c3428f0e73428220e6df838d5e
  * move lz4 to a subdir
  * move qrencode to a subdir
  * move vsock to a subdir
  * forgot to remove the old file in b2d0b2fb5e87bcae631a32a80b2d261e7b07d130
  * split paramiko and exec client code
  * move ssh bits to sub-directory
  * #3376 split directory listing, simplify calling async code
  * d3des is only used with rfb, move it there
  * #3376 oops: modules needs init file
  * normalize ssh args function arguments
  * use isinstance() rather than type()
  * remove debug logging
  * #3376 stub client quic connection
  * #3376 logging tweaks and fixes
  * #3376 for now, use wsproto
  * #3679 we may get memoryviews from compressors
  * strip header from more languages
  * prevent false positives with memoryview
  * #3682 no idea why this fails in github actions
  * #3642 fixed child_command_test in 256c7a7d5bf55ba31926eed8b62487989bd9b30f
  * fix all pylint warnings
  * fix all pylint warnings
  * f-stringify
  * we don't need the csc cython on RPM platforms
  * #3669 document splash=yes|no|auto
  * fix ssh parsing: need to switch to using dicts
  * test fixes and tweaks
  * #3642 less intrusive fix
  * #3667 minor test fixes
  * #3667 remove tons of dependencies we don't need
  * update dependencies for v4.4+
  * #3667 yasm is not needed
  * oops: don't normalize all display names to 'named-pipe'
  * add GHA build/test
  * teach run.py about --skip-*
  * #3675 also skip spurious 'Control_L' events when releasing the AltGr key
  * video_colorspace_test skip encodings unsupported by encoder
  * #3376 hook a basic http3 server
  * f-stringify
  * #3359 don't care about mpeg1 / mpeg2
  * better error message
  * #3359 make it easier to test a specific encoder
  * #3359 sample images for testing
  * constify memory alignment
  * #3359 x264 can handle odd widths with non-subsampled input
  * #3359 correctly parse the resulting pixel data
  * use strongly type accessors
  * better error messages
  * #3359 a codec can reject invalid input sizes
  * #3359 x264 can crash if given odd dimensions with subsampled input
  * add option to save compressed samples
  * #3359 add test case for video dimension masks
  * f-stringify and cleanup
  * fixup bd22fb3165a856fd7660c99ba63c9cb9f8be2af2 ('p' undefined)
  * fix minor lint warnings
  * don't show 'Upgrade' in splash title
  * f-stringify
  * guard against stdin / stderr goin MIA
  * #2174 include useful bug tracker link
  * doh: protocols don't include the separator
  * fix minor pylint warnings
  * #3599 ugly parse_host_string() function was now unused
  * fix minor pylint warnings
  * 'join' is what we have to use to wait for threads
  * unused import
  * fix minor pylint warnings
  * continue to support CentOS 8.x and clones
  * unused import
  * #3376 aioquic needs the openssl headers
  * #3376 missed the actual files in ff7d58e7deea6d79e4166dece97d47f47f5410c1
  * #3667 older versions of Pillow insist on a full palette
  * #3667 show full encoder parameters when failing
  * #3376 rpm packages for aioquic and pylsqpack
  * Update RPM.md
  * fix minor warnings
  * this is where docs really belong..
  * revert most of 23a0555bc94f530b78b7673526846099d60f0d6d
  * revert 23a0555bc94f530b78b7673526846099d60f0d6d
  * move docs to fs/
  * #3670 fix ssh desktop start with older servers
  * #3592 match all related subcommands
  * #3668 update bug tracker link to use github
  * Raise clarity: xpra install on server&client
  * #3667 fix error handling
  * Raise clarity: xpra install on server&client
  * Update README.md
  * Raise clarity that xpra install on server&client
  * #3662 values from the URL take precedence
  * #3664 symlink creation errors don't need a backtrace
  * bump year
  * 3664 send the full version when requested
  * #3471 support expanding chdir option
  * #3659 use dataclasses improve the code
  * simplify: lookup packet_type just once
  * round sizes up, so we never get '0KB'
  * fix warnings on Ubuntu 20.04
  * #3599 rename 'unix-domain' to 'socket'
  * #3647 disable bandwidth-detection by default
  * #3599 move more ssh parsing to a separate function
  * fixup 18720c1f1d9fcade877c6174c7ef65d6580471ea
  * fixup 18720c1f1d9fcade877c6174c7ef65d6580471ea
  * #3647 don't blacklist any Intel cards
  * #3599 don't override main attributes with query string values
  * #3651 client should almost be required
  * #3514 env vars must be strings
  * #3599 use urllib.parse rather than custom code
* Tue Oct 18 2022 scott.bradnick@suse.com
- Update to version 5.0+git20221018.223dc02f:
  * move nvidia codecs to 'Suggests'
  * #3651 use dh_movefiles to split the modules into separate packages
  * fix logging of decompressed messages
  * revert 0d37df6807729c865cd216f3b4d5eeba2e8f6817
  * server last info may have more data
  * f-stringify
  * remote logging of f-strings
  * #3582 expose gstreamer version info when FULL_INFO=1
  * #3582 these lib versions are no longer exposed by default
  * #3651 we have to use dh_shlibdeps
  * minor warnings
  * oops: undo parts of 6fc032eda4ae23917ed770c3d6f1249b3efafa55
  * fix chunked file uploads
  * make it possible to force chunking
  * ensure we don't try to process empty files
  * f-stringify
  * warn if we ever somehow get the wrong arguments here
  * this is a text file
  * only update one file
  * fix conf files not updated on Posix OSes
  * return change boolean just like the superclass
  * return change boolean just like the superclass
  * simplify: let update_focus() return the boolean
  * #3654 disable mixins we don't need
  * #3649 block the import of pycuda on WSL
  * #3651 split nvidia codecs into their own package
  * #3651 split packaging for DEBs
  * replace assert with explicit check
  * no need to raise an exception
  * Allow --max-size and --min-size to work again
  * the symlink is now in git
  * make it easier to build debian packages of xpra
  * #3651 move all cuda files to xpra-codecs-nvidia
  * #3652 add explicit conflict
  * #3651 split nvidia codecs into a separate package
  * #3590 avoid video for small sizes
  * f-stringify
  * #3514 disable GTK HiDPI by default
  * explicitly disable all codecs that use CUDA
  * #3648 ignore alpha if client can't handle it
  * forgot to update some codec references during refactoring
  * minor warnings
  * oops: fixup 105669b79fb522451f094dd2133be548ccd24966
  * oops: forgot to update paths here
  * #3582 the filters never change
  * #3582 limit default network and sys info
  * simplify
  * replace 'asserts' with faster 'RuntimeException's
  * remove unused var
  * disable transparency early via env var
  * #3646 filter out rgb formats with alpha
  * better debug logging
  * make it easier to run the examples
  * make pillow optional in more places
  * the proxy can be used for other modes
  * more minor warnings
  * minor warnings
  * fix minor warnings
  * use shorter method
  * fix minor warnings
  * fix more warnings
  * oops: forgot to update paths in tests
  * doh: typo
  * avoid errors when running without pillow installed
  * fix minor warnings
  * f-stringify + avoid more warnings
  * fix minor warnings
  * f-stringify and simplify
  * add link to #3633
  * forgot to bump the version here
  * try to ease upgrades from previous versions
  * derp
  * remove scary warning when pillow is missing
  * pillow, cryptography and xrdb are not strictly required
  * I have newer headers installed...
  * we don't have usable evdi libs on Fedora
  * make pillow optional again
  * less scary message when we can't load webcam components
  * make python pillow optional again
  * missed from move in fa3e6ed7a02c4a5e8aef95102431c423df25c689
  * fix minor warnings and f-stringify
  * fix building with clang
  * all supported distros have tmpfiles.d, including el9
  * #3592 simplify
  * less scary message when v4l2loopback is not installed
  * #3592 warn that these options are deprecated
  * #3592 warn if not building for 64-bits
  * #3592 re-arrange codecs
  * minor lint warnings
  * #3592 move nv_util with the other nvidia bits
  * minor lint warnings
  * #3592 split codecs into their own package
  * #3592 remove python3 package name prefix
  * #3592 libfakeXinerama is being deprecated
  * #3592 remove support for coexisting with python2 RPMs
  * #3390 forgot to include the compat file in sdist
  * these files no longer exist or have moved
  * cosmetic
  * #3636 also convert to bytes here
  * #3636 lz4 memoryview data must be converted to bytes
  * cosmetic
  * #3641 enable agent forwarding by default
  * #2303 also remove invalid non-symlink
  * simplify and update docstring
  * #2303 stash env option in display args
  * #2303 preserve the actual display
  * unused import
  * #3592 stub vpl encoder
  * #3592 simplify: just require 64-bit
  * unused import
  * fix minor warnings
  * remove unused def
  * #3592 bump minimum version requirement
  * #3592 remove support for older versions of libvpx
  * #3592 simplify: require libvpx 1.8
  * simplify
  * undo WIP from c86d1aaeadadd6c403997d218552e77a9a45ea5e
  * #3637 update Xdummy documentation links
  * remove redundant string prefix
  * f-stringify
  * don't log huge invalid packets, ellipsize them
  * Fix test_root_window_model by formatting geometry string correctly
  * Fix test_get_version_info when the revision is 0
* Sat Oct  1 2022 scott.bradnick@suse.com
- Update to version 4.4+git20221002.1c1e6e0d:
  * bump version
  * add rocky / alma / oracle / centos stream
  * add latest fix
  * #3454 too easy to hit resizing loops with xterm
  * show variants if we find any
  * #3630 don't populate the full layout list if we don't have to
  * f-stringify
  * #3630 add test that causes wayland hang
  * can only join strings
  * #3630 make it easier to disable all 'after-handshake' calls
  * fix missing systray on Ubuntu
  * the nvjpeg flag has been split in 2
  * build witout cuda on Fedora 37
  * add an empty changelog
  * #3628 try harder to find the 'interactive' version
  * silence some minor warnings
  * chop large opengl renderer strings when displaying them in UI
  * #3628 fix support for cygwin ssh servers
  * remove warning on MS Windows and MacOS
  * update the release notes
  * #3628 cygwin probably behaves like msys
  * some opengl renderer strings can be very long
  * refactor: split authandler
  * simplify: don't copy options we don't reuse
  * match any variation of 'gnome' DE
  * #3628 oops, emulate the output format too
  * typo
  * #3628 match registry query as a plain string
  * #3628 re-arrange workaround order
  * #3626 we can query without cmd.exe scripting
  * add some new definitions
  * #3628 use paexec to get an interactive desktop
  * silence warning
  * silence warnings: access 'daemon' directly
  * #3626 try harder to locate xpra on MSYS2
  * #3626 honour more virtual commands execution on MS Windows
  * fix for loading 'DSS' keys, aka 'dsa' files
  * doh: check we found the keyclass
  * #3626 correctly handle channel exec requests
  * add funding link
  * replace chan_send with sendall variants
  * missed brotli compressor from clean list
  * never try to use systemd-run on MacOS
  * cosmetic
  * also clean the uuid
  * add utility for dumping xpra's x11 properties
  * delete the mode property on exit
  * cosmetic
  * doh: cut&paste gone wrong
  * refactor authorized keys parsing into a reusable function
  * refactor and keep the first match
  * simplify
  * fix warnings
  * refactoring + try to honour 'echo'
  * cosmetic
  * #3625 downgrade to a warning
  * cosmetic
  * some exceptions have no message
  * fix '_proxy' mode: don't start a server
  * verify we have a stdout array before accessing it
  * cosmetic
  * avoid errors with ssh sockets
  * #3626 don't use 'command' command on MS Windows
  * handle all '_proxy_*' subcommands generically
  * 'command' can be used without any arguments
  * f-stringify some more
  * don't show the full backtrace at 'error' log level
  * missing alias lookup
  * f-stringify some more
  * skip attempting to load codecs that aren't available
  * f-stringify
  * f-stringify and use mode aliases earlier
  * also skip 'importlib._bootstrap' as a debug category
  * use a more reliable timestamp server
  * unused import
  * add full backtrace at debug level
  * bail out if no GPU found
  * no visible logging during self-tests
  * #3625 skip showing scary warnings
  * f-stringify + fix warnings
  * add nvfbc to diagnostics
  * oops: missing exception variable caused an error
  * cosmetic
  * dependency is missing on Debian Bookworm
  * the debian headers are too old
  * the pkgconfig file takes care of the [lib]drm path
  * remove unused framework
  * pynvml 11.515.75
  * ffmpeg 5.1.1
  * update faac / faad url to maintained github fork
  * better libvpx url
  * 4.4 updates
  * #3625 add early check for nvidia driver
  * catch permission errors and report them
  * #3625 more consistent failure messages with missing hardware
  * use the correct loggers
  * keep the 'owned' flag updated
  * unused import
  * oops: no more hex
  * #3504 don't build the nvjpeg decoder by default
  * simplify
  * we must use print here
  * initialize variable so we can handle failures
  * remove support for gcc versions older than 6
  * f-stringify and fix warnings
  * f-stringify and fix warnings
  * fix legacy packet encoders
  * f-stringify
  * #3390 PoC expand server
  * don't use GLib directly
  * don't use GLib directly
  * #3473 also clamp pre-mapped windows
  * f-stringify
  * also makes the code less dense?
  * more generic solution for missing menu items
  * the qr menu may be missing
  * no wayland here..
  * when failing to parse, return 'auto' value
  * simplify validation
  * xsettings watcher may be None
  * f-stringify and fix warnings
  * shortcut out, avoids backtrace splatter
  * type annotation was wrong
  * free wrapper explicitly to avoid warnings
  * #3390 add drm as a pseudo codec
  * Fedora 37 needs an updated Cython
  * #3390 the cursor fix is in 1.9.1
  * #3390 add compatibility glue for older cursor function
  * #3390 add compatibility glue for older versions
  * Cython 3.0 alpha: use pre-release to support python 3.11
  * #3622 handle config file parsing errors more gracefully
  * #3390 dumb double buffering
  * round seconds
  * f-stringify
  * late_start() should only run once
  * log real errors, ignore missing PIL
  * #3390 oops: forgot to add drm module
  * don't import logger if we don't need it
  * skip scary permission warning for socket dirs in XDG_RUNTIME_DIR
  * f-stringify
  * split method
  * cosmetic
  * f-stringify
  * fix logging call
  * win32 DotXpra only uses 'username'
  * disable clipboard proxies until we have a peer for them
  * better window info
  * silence pylint warning
  * minor warnings
  * pycuda depends on numpy
  * restore missing numpy import
  * typo + add reset_logging()
  * constify and cleanup
  * save as jpeg, bail out sooner
  * use ValueError
  * cleanup and remove python2 support (simplify)
  * f-stringify
  * #3619 better exception message for payload size errors
  * #3619 don't compress strings
  * #3390 cleanup and f-stringify
  * oops, fixup missing import from 3c02e27631d982f0540aac9be0d87272529c74d6
  * raise min version
  * f-stringify and minor warnings
  * validate screen dimensions, round if necessary
  * #3483 move most of the locking to cuda_context import
  * better server / session type string (we don't use gtk2)
  * try to normalize mode names better
  * #3390 move finding devices to a reusable function
  * cleanup and f-stringify
  * delay bindings imports until actually needed
  * f-stringify
  * #3390 make save-to-file optional (too slow)
  * validate platform earlier, remove duplicated check
  * #3390 typo: check for 'libdrm'
  * #3390 add kernel module loading helper
  * #3390 move drm to its own module
  * f-stringify and fix pylint warnings
  * #3390 expose drm info when FULL_INFO>1
  * silence pylint warning
  * #3390 cleanup and f-stringify
  * #3390 build dependency updates
  * #3458 we have ffmpeg builds now
  * #3390 add drm query tool
  * #3390 update to latest API
  * #3390 no need for info logging, we can use 'evdi' for debugging
  * f-stringify
  * #3616 add 'autoconnect' checkbox to dialog
  * better error format
  * typo
  * pylint warnings
  * f-stringify, fix minor warnings
  * f-stringify and pylint warnings
  * f-stringify and pylint warnings
  * f-stringify
  * f-stringify, fix minor warnings
  * use our pkgconfig file as template
  * don't use print()
  * assume that the user wants to abort authentication
  * fix pylint warnings
  * whitespace cleanup
  * update tests to use 'wants' array
  * fix minor warnings, avoid print()
  * avoid naked print() in reusable / exported functions
  * #3610 use the last line of output
  * #3610 detect which 'find' command to use
  * f-stringify and remove print()
  * #3524 support remote ssh start
  * oops: typo
  * linter warning
  * f-stringify
  * #3592 move towards generic feature requests
  * also update default file config
  * automatically enable sync-xvfb when using Xephyr or Xnest
  * f-stringify
  * f-stringify
  * also remove session tmp dir
  * f-strings and warnings
  * #3002 bail out if the user cancels pinentry
  * we can't call quit() directly from the authentication thread
  * prettify
  * f-strings
  * typo
  * f-strings
  * f-strings
  * #3478 tool for extracting atom names from values
  * open() warnings and f-strings
  * silence import warning
  * ensure tests don't use prompts
  * re-enable
  * simplify
  * remove unused argument
  * #3610 wait for a valid header on ssh connections
  * more cleanups, warning fixes, f-strings
  * fix more minor warnings
  * fix minor linter warnings
  * server time is better than using CurrentTime
  * use f-string
  * revert fb6621eaf922466a4210f2d03a973893e4bfa74c
  * re-use the superclass method
  * we don't have 'long's any more
  * bug: timestamp clamping should not shortcut out
  * log all the event data
  * simplify some more
  * simplify, a bit
  * update the release notes
  * preserve URL arguments in http request path
  * cosmetic: make code more readable
  * mostly cosmetic refactoring
  * fix error path ('reason' was undefined)
  * unused import
  * #3604 separate logging from gen-dir
  * don't use temporary variable with reserved name
  * OR windows don't have 'client-geometry'
  * f-strings
  * f-strings and fix lint warnings
  * convert to spaces
  * f-strings
  * need ssl attributes to parse
  * honour env to skip coverage
  * #3601 the lz4 compat header file must be included explicitly
  * we now support 1.8 or later
  * #3601 workaround for older versions of lz4
  * #3601 unit test
  * remove print debug statement
  * #3560 also update the client unit test
  * we have to query the keymap to get properties
  * typo
  * oops: missing import
  * remove unused import, add debug logging
  * remove unused arg
  * simplify: raise_xerrors=False is the default
  * unused import
  * silence lint warnings
  * when testing, disable lost-focus-exit behaviour
  * silence linter warnings
  * oops, that was for testing only
  * move x11 tests where they belong
  * #3582 honour FULL_INFO in get_host_info
  * pid is no longer included in host info
  * proxy attributes are now regular display attributes
  * silence some minor lint warnings
  * #3560 forgot to update unit test
  * #1796 make the 'all' list of challenge handlers configurable
  * vfb bits require the 'display' feature
  * remove unused imports
  * avoid None values
  * avoid more None values
  * bencode doesn't like None values
  * add missing indentation
  * build more codecs
  * skip test if numpy is missing
  * tests may not initialize all attributes
  * vfb bits require the 'display' feature
  * try to make it clearer this should not be used
  * skip the dbus test if python-dbus is not installed
  * also honour the PYTHON env var when launching subprocesses
  * typo
  * fix deprecation warning
  * don't use 'which' on absolute paths
  * cosmetic
  * make it possible to test with multiple interpreters in parallel
  * cosmetic
  * we can't import the enums directly
  * skip dbus test if python-dbus is not installed
  * also honour the interpreter here
  * fix uninitialized warning with latest Cython
  * #3373 enable libspng
  * doh: use the same interpreter for running the tests
  * make it easier to run with a different interpreter
  * distinguish connection errors from authentication failures
  * cosmetic
  * cosmetic
  * avoid deprecation warnings
  * oops: also remove import
  * refresh delay is no more (#3560)
  * silence warnings with newer versions of Pillow
  * #3486 never use print() directly from modules
  * better error diagnostics
  * return strings, not bytes
  * simplify
  * avoid errors when python-xdg is not installed
  * downgrade missing paramiko to a warning
  * catch missing python-dbus earlier
  * missing python-dbus is just a warning
  * error handling for menu loading
  * #3601 updated deps
  * #3572 we only need the lib
  * #3601 deb dependencies
  * #3100 cleanup the authentication handler interface
  * #3100 exit more quickly if the http connection requires authentication
  * #3100 make challenge handlers more re-usable
  * don't add the same digest value multiple times
  * cosmetic
  * #3100 make authentication method re-usable
  * #3100 'Basic' http authentication handler
  * cuda context locking contention should be a transient problem
  * the html5 client wants to know the frame type
  * #3598 expose 'low' 'scaling-quality' for nvenc and nvjpeg
  * avoid weird closure errors
  * f-strings
  * #3607 newer clients don't want flattened caps
  * easier to read
  * unused import
* Tue Aug 23 2022 scott.bradnick@suse.com
- Update to version 4.4+git20220823.6f83fe78f:
  * #3607 newer clients don't want flattened caps
  * easier to read
  * unused import
  * os.path.abspath always returns a path
  * MacOS doesn't have an XDG_RUNTIME_DIR
  * show what type of client disconnected
  * #3059 X11 pointer grabs
  * #3059 pointer grabs for win32 using ClipCursor
  * fix desktop servers
  * silence linter warnings
  * #3504 use async calls using a cuda stream
  * #3582 more fine grained filtering
  * re-use value from common
  * move icon functions to a more re-usable location
  * simplify
  * cosmetic
  * oops: 10 seconds is slow
  * #508 workaround win32 focus events
  * #508 also show progress of downloads
  * #508 use the Taskbar to show splash screen progress
  * remove unused 'display' argument
  * #1526 get dpi from comtypes
  * #3504 move nvjpeg code to a separate method
  * #3589 reset fraction and text and re-generating progressbar widget
  * try harder to prevent dangling timers
  * #3589 re-generate new buttons
  * add debug logging
  * remove unused 'tooltip' argument
  * better formatting
  * wrong positional arg
  * fix digest errors with unchunked file transfers
  * better formatting and f-strings
  * avoid errors deleting the temporary file
  * fixup version number conversion
  * drop meaningless 'python-XX' version
  * import errors can be handled generically
  * #3601 remove python-lz4 fallback
  * #3601 remove python-lz4 package dependency
  * #3601 don't require python-lz4 anymore
  * #3601 prefer our own lz4 cython module
  * remove debug
  * #3601 handle memoryviews
  * #3601 handle memoryviews natively
  * remove unused imports
  * #3582 don't assume 32-bit
  * silence some warnings
  * fixup c420dc9170ff08c2d3f3a602114ab0af82e09b8d
  * #3504 show pycuda context cleanup failures
  * x11 bindings return bytes
  * just one repeated typo
  * #2105 bundle libproxy.py (missed from 82b0698e55f591173a5afbd3df6048de60a4d987)
  * update embedded xxHash lib
  * #3592 use namespace for audio caps
  * skip empty values
  * #3592 move clipboard caps to a prefix
* Mon Aug 22 2022 scott.bradnick@suse.com
- Update to version 4.4+git20220807.c52d8ac10:
  * new git snapshot
  * .. and here
  * we can use the same list for '8' and '9'
  * oops: forgot to bump version
  * doh: wrong line
  * ffmpeg 5.1 deprecated 'channels'
  * use newer commit
  * pytools 2022.1.12
  * pbr 5.9.0
  * ffmpeg 5.1
  * python-lz4 4.0.2 + fix macro warning
  * with 'epel-next-release' installed, this is not needed
  * bump date
  * match layout update
  * #3600 try to build python3-lz4 for RHEL 9
  * #2105 detect proxy settings using libproxy
* Sun Aug 21 2022 scott.bradnick@suse.com
- Update to version 4.4+git20220801.cc03f573e:
  * obvious is obvious
  * simplify: cuda-device-context is a video encoder option
  * don't increase the quality artifically
  * don't special case video
  * remove 'text' special cases
  * #3420 add control commands for 'max' options
  * honour refresh attributes
  * #3420 honour max-quality in more places
  * #2105 bundle pysocks with MS Windows and MacOS binaries
  * #3572 brotli option toggles the module
  * 2105 install pysocks on MS Windows build machines
  * #2105 connections via proxies using pysocks
  * Cython 0.29.32
  * Cython 0.29.31
  * revert 4425c08d72e08d4d2f0fe487cdc5f03e99ba8c88 which causes crashes
  * #2779 shortcut for showing the documentation
  * #2779 try harder to find a valid documentation path
  * don't install the manual in a subdirectory
  * #2779 add a shortcut for showing all the shortcuts
  * warn about uinput
* Wed Aug 10 2022 Scott Bradnick <scott.bradnick@suse.com>
- Making adjustments as per https://build.opensuse.org/request/show/994288
  * Swapping out '--without-strict'
  * Using CFLAGS '-Wno-error=deprecated-declarations' for all flavors
  * Adding 'ExcludeArch:    %%ix86'
* Sun Aug  7 2022 Scott Bradnick <scott.bradnick@suse.com>
- Making adjustments for 'ffmpeg-4' vs. 'ffmpeg-5'
* Sat Aug  6 2022 Scott Bradnick <scott.bradnick@suse.com>
- %%{_libexecdir} issue was fixed upstream, cleaning up spec file
  * See https://github.com/Xpra-org/xpra/issues/3597
* Wed Jul 27 2022 scott.bradnick@suse.com
- Update to version 4.4+git20220726.a03b3f67e:
  * #3597 openSUSE Leap 15.4 still does not use libexec
  * always pop GDK errors
  * #3595 add man page entry
  * #3595 'exit-with-windows' option
  * fix removing monitor: logging was causing an error
  * layout may be 'None'
  * close the splash screen if it loses top level focus
  * #2630 these values aren't 'real' layout names, don't try to use them
  * #2630 modify shadow keymap when '--keyboard-layout=auto'
  * `xpra/x11/server_keyboard_config.py`: `'NoneType' object is not iterable`
  * #3594 fix vim typo
  * #3594 backwards compatibility fix
  * f-strings and more dense output
  * safer: don't delete recursively, delete with glob explicitly
  * when calling 'xpra clean' explicitly, we can remove session sub-directories
  * run 'late_cleanup' before trying to remove the session dir
  * don't try to parse 'resize-display' as a resolution if it is a boolean
  * remove spurious import added by IDE
  * distinguish directories from regular files
  * it is possible to run without the 'rgb' encoder
  * make it easier to build without any codecs
  * we can only use the 'native' mapping with existing x11 keycodes
  * simplify: remove unused argument
  * #3592 remove redundant 'xkbmap_' prefix
  * #3592 remove unstructured setxkbmap query data from server
  * #35822 start removing 'setxkbmap -query' and 'setxkbmap -print'
  * #3582 audio info may be missing - and that's fine
  * don't pretend that these versions should work
  * more resilient version parsing
  * #3592 remove xkbmap prefix from client
  * #3582 audio info may be missing - and that's fine
  * #3592 same as f192c0312bc98360aec94e6aa92af90511259401 but for the server
  * #3592 move keymap to a substructure
  * #2303 support agent forwarding with the builtin ssh server
  * cosmetic
  * #2303 ignore '_proxy' command line arguments
  * cosmetic
  * #2303 when client exits, find another auth socket
  * unused import
  * #2303 keep track of sock path
  * #2303 make function more re-usable
  * dead symlinks don't "exist"
  * #3592 remove unused tcp-proxy feature
  * typo - why didn't this trigger problems?
  * the 'install' subcommand does add data files
  * #2303 error handling
  * return the exit code
  * #3592 remove uncompressed 'premult_argb32' icon format
  * #3592 never use zlib for pixel data
  * unused import
* Tue Jul 26 2022 Scott Bradnick <scott.bradnick@suse.com>
- A few changes related to local builds of Leap 15.4 referencing 150500
* Fri Jul 22 2022 scott.bradnick@suse.com
- Update to version 4.4+git20220721.c00134211:
  * place the verification token at a random address
  * remove ancient mmap token location code
  * #3582 limit audio info
  * always enable bundling - no need for env switch
  * the '_proxy' subcommand doesn't need to load compressors
  * skip lib validation warnings when running 'sdist'
  * #3582 limit client info exposed
  * doh: return the info
  * return a dict even when we hit an error
  * #3591 clamp negative values to display
  * #3591 also drop negative dimensions
  * #2303 honour env var and skip processing ssh agent paths
  * some clients don't have ssh-auth-sock specified.. don't error out
  * silence linter
  * only forward ssl socket options to the ssl wrap function
  * fix ssl breakage: convert attribute names to arguments
* Fri Jul 22 2022 scott.bradnick@suse.com
- Update to version 4.4+git20220720.22e3ae211:
  * don't compress rgb pixels with anything but lz4
  * rename method to prevent confusion
  * #2303 ssh agent forwarding
  * #3582 hide detailed version info
* Wed Jul 20 2022 scott.bradnick@suse.com
- Update to version 4.4+git20220720.d0ae240e2:
  * #3582 skip opengl info
  * fixup estr logging method
  * #2303 make is_socket re-usable
  * #3483 pycuda also imports numpy
  * #3579 more f-strings
  * oops: missing import
  * #3582 mixins info, option to log capabilities
* Tue Jul 19 2022 scott.bradnick@suse.com
- Update to version 4.4+git20220719.d301bf723:
  * #3582 restrict client info exposed
  * the system tray forwarding is challenging
  * we are forced to use appindicator now
  * simplify
  * #3577 simplify
  * #3577 reorder
  * #3577 remove v4l2 legacy workarounds
  * typo
  * too many distros are missing pam pkgconfig files
  * not all Linux distros have this header file
  * another strangely misnamed package: libpam0g'
  * fix misnamed package dependencies
  * RHEL doesn't have a pam-devel package?
  * distros have all moved pam to /usr/include/security/pam*
* Mon Jul 18 2022 scott.bradnick@suse.com
- Update to version 4.4+git20220718.6b84ef9f6:
  * skip all guessing using an env var
  * #3386 fix typo
  * procps-devel is not available on RHEL?
  * pam pkgconfig refs had gone missing
  * refer to Cython 'Extension' class directly
  * oops: nvenc is not a package
  * make it easier to change the number of cores used
  * ignore 'address' warnings building nvenc
  * use booleans for switches
  * no longer used
  * try the local cuda symlink before anything else
  * this doesn't do anything
  * make it easier to choose the number of threads
  * #3577 remove legacy workarounds
  * #3577 add switch for 'argb' codec
  * #3577 group subsystems together
  * #3577 group macos / win32 bundling workarounds together
  * #3577 nvenc must use pkgconfig
  * #3577 enable '-DDEBUG' globally
  * #3577 convert pam module in pkg-config
  * CUDA symlink on MS Windows:
  * #3577 move nvenc tweaks to pkgconfig file
  * ignore temporary build generated installer file
  * #3390 evdi uses c++
  * #3577 use pkgconfig file for nvfbc flags
  * #3577 simplify nvenc / nvjpeg using pkgconfig files on win32
  * #3584 typo
  * fixup bccf36d62f6857094054cb3bd5cefd70b1fd5423: directories must start with a '/'
  * #2753 RPM file list update
  * #2753 add new packaging dependency
  * #3582 limit the info available to remote hosts
  * convert tray menu to use the new qrencode module
  * #56 fix miscalculation of initial refresh rate
  * #3583 update to the new python-cryptography API
  * #3579 (almost) finish this one module
  * #3483 only import numpy once, block if necessary
* Tue Jun 21 2022 scott.bradnick@suse.com
- Update to version 4.4+git20220621.872c7f8d8:
  * #3559 set non zero global quality with vaapi
  * #2400 more indirect dependencies
  * add example pkgconfig files
  * #3543 make it easier to disable inotify watcher
  * move away from slow zlib compression
  * #3556 don't enable hevc by default
  * report codec information using strings
  * add docstring
  * add missing codecs to clean list
  * #3457 add missing toggle for avif
  * #3553 extra args for vfb command
  * Update randr_bindings.pyx
  * Allow override of idealVSync by env. vars
  * Fedora 36 build fix: use a more crude glob
  * doh, typo
  * #3458 disable LTO on Fedora 36
  * new upstream release: 11.515.48
  * show builds from 'git master' as 'beta' builds
  * utility function to hide platform import ugliness
  * better error message formating
  * #3552 only initialize X11 gdk display source on X11..
  * #56 this function must return an int
  * #56 we may have already added this mode
  * #56 don't bother with xinerama workaround when we have randr16
  * better wording
  * oops: was meant to specify the list values
  * fix more warnings
  * silence some minor warnings
  * make code more readable
  * error message would itself cause an error
  * fix chunk number verification
  * cosmetic
* Tue May 31 2022 scott.bradnick@suse.com
- Update to version 4.4+git20220531.56f76c715:
  * fix new warnings generated by latest Cython / gcc on win32
  * also avoid deprecation warnings on win32
  * Update OpenGL.md
* Wed May 25 2022 scott.bradnick@suse.com
- Update to version 4.4+git20220523.d5a721cc4:
  * fix webcam forwarding with older versions
  * Most build systems respect the CPP env var instead of just calling cpp
* Sat May 21 2022 scott.bradnick@suse.com
- Update to version 4.4+git20220521.cb25967f8:
  * #3545 opensuse does patch distutils
* Fri May 20 2022 scott.bradnick@suse.com
- Update to version 4.4+git20220519.9be098cc7:
  * #3371 set the server socket even if we don't forward xdg-open
  * we need a frame ancestor to use StreamSaver.js
  * Cython 0.29.30
  * trays don't have a 'client-geometry' to adjust
  * if we fail the checksum, delete the file
  * refactor hash checking functions
  * detect AlmaLinux and Rocky-Linux
  * make code more readable?
  * almalinux list of packages is the same as centos
  * minor fixes
  * update to use cuda 11.7 path
  * #3537 forward port d0d2bae8ad825685a9301855924f3468ae39767d
  * fix debug logging triggering warnings
  * better warning message: include the key
  * #3537 remove DesktopManager and DesktopState
  * #3537 remove overcomplicated ownership-election
  * #3537 clamp window models to the new screen size
  * more understandable message
  * simplify: size can be passed in, no need for a callback here
  * back off more gradually
  * the 'title' lives in the model
  * #3390 stub evdi capture codec
  * try harder to distinguish connection failures vs lost connections
  * only do the context check if we actually access X11 functions
  * log failures to cleanup contents handle
  * use the correct short names
  * these are the correct short names apparently
  * try harder to show a useful hostinfo
  * #3530 always use the free_image_wrapper method to ensure we safely access X11 using the context manager
  * prevent name conflict between errno value and enum
  * make it possible to call clean multiple times without causing errors
  * #3535 only unescape what we use, URL handlers can handle it raw
  * #3486 more thorough testing of json input
  * #3486 indent error details
  * #3486 can't catch an error we can't import
  * fixup c5f7c8804a87eb725e699045800b00322a4633e1: add to the correct prefix
  * #3486 add MSYS2 dependency
  * #3486 add suggested dependencies
  * #3486 fix keycloak auth module thanks to unit tests
  * #3535 unescape URLs
  * force rebuild
  * some distros choke on zstd
* Thu Apr 28 2022 scott.bradnick@suse.com
- Update to version 4.4+git20220428.94954180d:
  * #3533 newer versions of Firefox use smaller max-size
  * make socket info more resilient
  * only query ioctl if we have a valid file descriptor
  * move command lookup by pid to window model
  * #3530 don't send pixels for windows that don't overlap the screen
  * #3530 add 'unityhub' as browser content type
  * #3514 fix launch error on systems without X11
  * fix tabulation
  * log failures to undock systrays
  * #3530 crop the damage area if the window is now smaller
  * add the v4l2 source to the codec loader tool
  * #3371 guess the session if the environment has it
  * parse when called, don't return a generator
  * #3384 pass shadow geometry options to remote server
  * fix generic subcommand substitution
  * file should have been removed as part of 0b23cc0e59fd55047e5e73df7a4d39439584fb2d
  * make the code easier to parse using context managers
  * log the previous dimensions
  * use xsync context manager
  * #3530 use a UI context manager for freeing X11 images
  * don't use xsync context manager on MacOS
  * import X11 error handlers from the correct place
  * #3530 cleaning up the xshm handle may raise X11 errors
  * #3530 add more context checks
  * #3530 call context check when XShm resources are freed
  * lintian hangs on aarch64, skip it
  * #3524 don't modify the monitors when the client connects
  * remove debug logging
  * #3524 make monitor windows fullscreen when desktop-fullscreen is set
  * #3524 remove functions identical in base class
  * #3524 doh: modify the monitor we're setting properties on
  * #3524 better debug logging
  * #3524 refresh all monitors on layout changes
  * #3524 add 'monitor' subcommand
  * #3524 reconfigure monitor models on external resize event
  * #3524 add stub for handling monitor resizing via xrandr
  * add missing context check, XRRSelectInput wrapper
  * #3486 style fixups
  * Refactoring for PR
  * Refactoring for PR
  * #3524 fixups, cleanups, etc
  * cast is not necessary here
  * Refactoring for PR
  * Added keycloak authentication
* Tue Apr 19 2022 scott.bradnick@suse.com
- Update to version 4.4+git20220419.138728c46:
  * #3524 allow the client to add and remove monitors
  * always log the full backtrace
  * #3524 handle individual monitor resizing
  * #3524 doh: don't modify the event which may be used elsewhere
  * #56 / #3524 allow multiple monitors in 'resize-display' option
  * #3524 disentangle 'set-initial-position' and 'requested-position'
  * use 'damage' logging
  * pylint warnings
  * #3524 multi monitor desktop mode
  * #56 let the build auto-detect which variants should use Xdummy
  * we need the dummy installed to check the version number
  * #56 use Xdummy on Debian: add dependency
  * discard invalid workarea values
  * #56 we don't support multiple screens
  * remove debug logging
  * #56 let's hope that newer Debian versions no longer mess up the X11 server
  * #56 ensure the commented out Xdummy command line is valid
  * fix error if XDG_DATA_DIRS is not set
  * #56 make get_monitor_properties reusable
  * we don't support multiple screens, only monitors
  * Fix shadow server test following changes in #3476
  * oops: messed up patch context
  * #56 add disconnect patch to dummy driver builds
  * #56 enable the new exact monitor layout matching code
  * #56 match monitors and outputs
  * #56 try to disable unused crtc's outputs
  * fix benncode error when cuda info is missing
  * oops: using floats breaks backwards compatibility (bencode)
  * #3518 ffplay is video
  * #3519 use 'scroll' encoding more judiciously
  * update patch has zero fuzz
  * #56 keep track of primary monitor, prettify_plug_name
  * #56 enable Xdummy on arm again
  * build the dummy driver on arm64, always build xpra
  * ffmpeg 5.0.1
  * oops: we do still want those
  * #56 build updated dummy driver for Debian distros
  * simplify: don't enable by default on MacOS or MS Windows
  * MacOS needs a Python interpreter to run the signal listener
  * #3493 fix signal watcher libexec path on MacOS and MS Windows
  * ship xpra_signal_listener on MacOS
  * debug logging tweaks
  * fix setting of monitor attributes
  * provide XSync method, use it instead of (useless) XFlush
  * make it easier to initialize DPI awareness without loading GTK
  * latest pillow spits out warnings without this
  * #56 hook up monitor virtualization in seamless server
  * validate mapping size
  * oops: missed during renaming
  * remove unnecessary import
  * use a stronger type for membuf
  * #3504 use a MemBuf to quickly allocate host memory
  * use correct value for bits-per-pixel
  * #3504 make it clearer this is a CUDA buffer
  * #3504 simplify: don't use a download callback
  * explicitly unregister the CUDA RegisteredBuffer
  * #1467 remove redundant pointer limits patch
  * #56 oops: fix backwards compatibility for add_screen_size
  * #56 add modes to output as needed
  * add XSynchronize and XSync wrappers
  * #3366 pixel data is a list of bytes
  * re-use CurrentTime from pxd
  * #56 configure crtcs, outputs and monitors
  * #56 expose monitor info
  * #56 expose primary output, hide gamma for disconnected outputs
  * #56 also include gamma curves
  * #56 set WIDTH_MM and HEIGHT_MM dummy output properties
  * #56 skip irrelevant information
  * #56 capture most crtc / output info
  * #56 switch to milimeters everywhere
  * fix memleak: add missing XRRFreeOutputInfo
  * non ui clients may not have 'screen_sizes' defined
  * make it easier to dump monitor info
  * #56 make the legacy dummy dpi option optional
  * allow a wider range of clocks
  * #3504 free buffers as soon as possible, log alpha channel merge cost
  * #56 oops, missed from a6248574105da32680a9cb2b624cc6d9cf896688
  * #56 enable dynamic resolution matching with randr >= 1.6
  * #56 with dummy 0.4.0 or later no need for pre-defined modelines
  * minor path / extension fixups
  * fix patch path, remove merged patch, use bz2 archive
  * dummy v0.4.0
  * fix 'jpega' decoding using plain 'jpeg' decoder
  * #3504 add 'jpega' support
  * also add jpeg / nvjpeg encoders
  * pylint warning
* Fri Apr  8 2022 Scott Bradnick <scott.bradnick@suse.com>
- Adding 'Recommends: lsb-release' so 'Information' -> 'Session Info'
  returns results vs. 'unknown'.
* Fri Apr  8 2022 Scott Bradnick <scott.bradnick@suse.com>
- Removing 'BuildRequires: lsb-release'.
* Fri Apr  8 2022 Scott Bradnick <scott.bradnick@suse.com>
- Adjusting to use 'distribution-release' for Tumbleweed and
  'openSUSE-release' for < Tumbleweed.
* Fri Apr  8 2022 Scott Bradnick <scott.bradnick@suse.com>
- Swapping out 'openSUSE-release' (for 'distribution-release') BuildRequires.
* Thu Apr  7 2022 Scott Bradnick <scott.bradnick@suse.com>
- xpra-paths.patch has been removed because the developer @totaam committed
  https://github.com/Xpra-org/xpra/commit/0ed231fb95c8df3ec97d779698e6818faa7e5ef8
  as a result of https://github.com/Xpra-org/xpra/issues/3501 "build tweaks for openSUSE"
* Tue Apr  5 2022 Scott Bradnick <scott.bradnick@suse.com>
- Updating .spec to accomodate TW (libexec) vs. Leap (lib) for %%{_libexecdir}.
* Mon Apr  4 2022 scott.bradnick@suse.com
- Update to version 4.4+git20220404.1e56be683:
  * #3503 don't use gtk for reading atom names
* Mon Apr  4 2022 scott.bradnick@suse.com
- Update to version v4.3+git20220402.2f1c3abe7:
  * #3504 manage the cuda context outside the nvjpeg decoder
  * #3504 cuda gpu buffer transfer for opengl backend
  * #3509 protect access to mutable data
  * check if paths exist before
  * check XDG_DATA_DIRS/icons for pixmaps
  * remove unused declarations
  * #3509 prevent potential race condition
  * don't use arrays if we can use tuples
  * #3504 use pycuda rather than Cython
  * don't store cython generated file
  * #3504 common python definitions cannot live in pxd
  * move common definitions to pxd file
  * #3505 override sourced env with command line
  * #3505 command line can override config files
  * validate the option we're dealing with
  * #3458 revert f5b1b663bd981b326c4720731b7c97a007b2b247 now that cuda 11.5.2 supports GCC 12
  * try to build with gcc 12
  * arch=all triggers warnings, silence them
  * #3505 skip 'false' values
* Tue Mar 29 2022 Scott Bradnick <scott.bradnick@suse.com>
- Adding a few missing BuildRequires/Requires/Recommends.
* Tue Mar 29 2022 scott.bradnick@suse.com
- Update to version git20220328.5881281f1:
  * #3504 add nvjpeg decoder
  * remove unused definitions
  * misaligned positional arguments
  * remove unused definitions
  * prefer immutable tuples
  * workaround for libx264 version numbers
  * export 'relative-position' and 'parent' from X11 shadow servers
  * doh: group-leader and transient-for had gone AWOL
  * #3476 support OR windows in shadow servers
  * add debug logging to video delay calculations
* Tue Mar 29 2022 Scott Bradnick <scott.bradnick@suse.com>
- Initial version for xpra with 'xpra-html5' pulled out.
* Mon Mar 28 2022 scott.bradnick@suse.com
- Update to version git20220328.5881281f1:
  * #3504 add nvjpeg decoder
  * remove unused definitions
  * misaligned positional arguments
  * remove unused definitions
  * prefer immutable tuples
  * workaround for libx264 version numbers
  * export 'relative-position' and 'parent' from X11 shadow servers
  * doh: group-leader and transient-for had gone AWOL
  * #3476 support OR windows in shadow servers
  * add debug logging to video delay calculations
* Sat Mar 26 2022 scott.bradnick@suse.com
- Update to version git20220326.5fd33c46d:
  * export 'relative-position' and 'parent' from X11 shadow servers
  * doh: group-leader and transient-for had gone AWOL
  * #3476 support OR windows in shadow servers
  * add debug logging to video delay calculations
  * never delay unless we have a video region
  * log damage image and scroll latency
  * remove unused code
  * #3501 build tweaks for openSUSE
  * #3477 fixup opengl probing (again)
  * #3502 control command for (un)setting start env
* Fri Mar 25 2022 scott.bradnick@suse.com
- Update to version git20220325.7f8ca92ba:
  * #3477 fixup opengl probing (again)
  * #3502 control command for (un)setting start env
* Thu Mar 24 2022 scott.bradnick@suse.com
- Update to version git20220324.785a44e79:
  * #3476 relative window position tracking
  * #3493 forgot to update mswindows exe script path
  * #3493 no need for a man page if the command is hidden
  * missed from d5e3d9b1d0248cca7fc265f5d390e0b9d63a7a82
  * move manual to subdir of /u/s/doc/xpra
  * typo
  * fix distutils deprecation warning
  * #3493 move signal watcher to libexec
  * #3493 these files have moved
  * #3493 'fs' should mirror the real paths
* Wed Mar 23 2022 Scott Bradnick <scott.bradnick@suse.com>
- Updated to the following source version(s):
  * xpra_ver 4.3.2
  * html5_ver 4.5.2
  * uglifyjs_ver 3.15.3
- Added pkgconfig requirement for 'xres'.
- Added a few new/missing items for '%%files'.
* Wed Dec  1 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Drop unused pkgconfig(pygtk-2.0) BuildRequires: Not used since
  version 4.0, when python 2 support was dropped.
- Add pre, post, preun and postun handling of xpra.socket.
* Mon Oct  4 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 4.2.3
  * network layer:
    + ensure the http headers cache is never modified
    unintentionally
    + invalid packet encoder names should not cause fatal errors
    + preserve audio packets chunking (avoids an HTML5 client
    bug)
    + prefer https links
    + prefer sha256 to sha1 for file transfer checksums
    + mmap setup error handling
    + `sndbuf_bytes` value was incorrect (currently unused)
    + socket timeout too long - broke VNC connections
    + AES DoS with unreasonably large number of password
    stretching iterations
    + tone down http content security policy for the HTML5 client
    + parsing of remote ssh command output
    + reply with a 404 if we have no http data to send
    + stricter validation of challenge digest attribute
    + stricter validation of packet indexes
    + specifying invalid compressors should not be fatal
    + handle more VNC clients correctly
    + server errors when VNC clients are connected
    + proxy sessions not found due to socket-dirs
    + mmap group lookup
  * encodings:
    + don't enable video encoders not present in 'encodings'
    option
    + ffmpeg H264 errors with unreleased version
    + ffmpeg codecs silencing too many warnings
    + vpx encoder lossless mode detection
    + potential race conditions in the proxy server's encoder
    loop
    + visual corruption with scaled jpeg updates
    + incorrect error messages with the jpeg YUV decoder
    + error in 'void' paint events (currently unused)
    + CUDA 11.4 and Ampere cards
    + RPM build errors when CUDA is disabled
    + restrict the number of NVENC errors tagged as transient
    + more robust OpenGL picture decoding sanity checks
  * packaging and platforms:
    + find the fakeXinerama library more reliably on all
    platforms
    + platform detection for CentOS / RedHat
    + missing default configuration files on MS Windows
    + missing webp with latest Pillow builds on MacOS
    + build fix for non-amd64 Debian (missing nvfbc)
  * clipboard selections getting stuck with MS Windows and MacOS
    clients
  * clipboard errors with some packet encoders sending strings
  * authentication modules not honouring `socket-dirs` option
  * make it easier to dismiss the splash screen
  * ssh password and key dialogs timing out without being shown
  * menu loading race condition causing empty start menu
  * window size hints may not have been honoured (rare case)
  * honour the force-replace-wm flag when upgrading
  * correctly handle command timeouts when probing servers
  * test scripts and command line tools fixups: unit tests, U2F
    tool, audio test, etc
  * system tray save-to-file debugging failures
  * minor cosmetic fixes to logging messages, unreachable code,
    icon loading errors
  * make it easier to run in a prefixed installation
- Update xpra-html5 to version 4.5.1 and uglify-js to 3.14.2
* Tue Aug 10 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 4.2.2
  * don't build ffmpeg codecs on i386 (crashy)
  * prevent crashes caused by svg conversion done in a thread
  * always stop the 'new-stream' notification process
  * prevent subprocesses from becoming zombies
  * clean server on 'stop' or 'exit'
  * fix application geometry issues
  * show correct default values with "xpra --help"
  * stop responding to 'info' requests when shutting down
  network layer:
  * honour the packet-encoding and compressors options
  * rencode packet encoder is not thread safe!
  * packet errors with bencoder and None values
  * don't assume the packet encoders handle bytes and / or
    strings
  client issues:
  * backwards compatibility with v3 servers for ssh start
  * incorrect client exit code
  subcommands:
  * 'start-gui' invalid options shown
  * 'sessions' and 'displays' subcommands do not need a display
  * fix hidden 'wmname' utility subcommand
  * many subcommands should send debug logging to stderr
  menu loading:
  * try harder to find valid menu entries to use
  * skip entries that cannot be executed
  * don't block the main thread when loading menus
  xpra top:
  * handle unicode window titles correctly
  * fix screen corruption due to threading
  * fix latency always showing as zero
  audio:
  * pipeline errors with aac encoder
  * X11 warning when starting microphone forwarding from the
    command line
  minor / cosmetic fixes:
  * cropped icons shown in html5 client connect page
  * logging, error handling
  * remove unused pulseaudio directories
  * '1080p' resize-display string matching
* Sun Jul 11 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 4.2.1
  build and packaging fixes:
  * missing dependencies
  * remove unused outdated code
  * remove runtime dependency on distutils for 'which'
  * cryptic error when a pkg_config file is missing
  proxy server:
  * deadlocks when queues fill up too quickly
  * honour mode and display
  * disconnections under heavy load
  Network:
  * fix RFB server protocol, sockets not timing out with VNC
    clients
  * invalid error when bind option points to a directory
  * detect wifi network connections more reliably
  * fix 'xpra' packet type auto detection
  * default to ssl-mode if the 'wss' socket option is not
    specified
  * 'keydata' connection attribute should override other options
  * correct exit code for encryption errors
  Encodings:
  * disable vaapi in ffmpeg codec by default (crashy / buggy)
  * NVENC errors when retrying after a transient failure
  * scroll detection bugs
  * webp encoder invalid memory access (corruption)
  Misc:
  * notification forwarding errors with SVG icons
  * disable SVG icon resizing (potential crashes on some
    platforms)
  * missing log prefix for 'xpra recover' subcommand
  * faster server startup failures: don't wait for things that
    were not started (ie: audio)
  * fix commands started twice when upgrading (ie: ibus-daemon)
  * local start with explicit attach was broken on Posix
  * 'attach' option should not be forwarded to the server (which
    then fails)
  * invalid window resize counter (used for resize loop
    prevention)
  * missing icon errors when html5 client disconnects from
    system-wide proxy server
  * file transfer errors when a 'top' client is connected
  * don't claim that non-interactive clients use the screen
  * retry once after X11 query tree errors during startup
  * provide XDG_RUNTIME_DIR if it is not defined
  * add new 3x4K Xdummy modeline
  * minor cosmetic and debug logging fixes
* Sun Jun 20 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Add python3-pyinotify as recommended dependency to allow watch
  for video device changes
* Sat Jun 12 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 4.2
  * use pinentry for password prompts and ssh prompts
  * nvjpeg encoder - also requires this commit to the html5
    client
  * gui for starting remote sessions
  * new subcommands: recover, displays, list-sessions,
    clean-displays, clean-sockets - #3098, #3099
  * many fixes: window initial position, focus, non-opengl paint
    corruption, slow rendering on MacOS, build scripts, handle
    smooth scroll events with wayland clients, always lossy
    screen updates for terminals, clipboard timeout, peercred
    auth options
  * support multiple clients using mmap simultaneously with
    non-default file paths
  * only synchronize xsettings with seamless servers
  * automatic desktop scaling is now disabled
  * workaround for gnome applications starting slowly
- Update uglify-js to 3.13.9
- Refresh xpra-paths.patch
* Fri May  7 2021 Dirk Müller <dmueller@suse.com>
- fix build on architectures without pandoc
* Fri Apr 23 2021 Luigi Baldoni <aloisio@gmx.com>
- Fix build with ffmpeg 4.4 on Leap
* Wed Apr 21 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 4.1.3
  * fix window geometry constraints being applied wrong
  * fix xpra start failures when the display is already running
    (with use-display=auto)
  * fix vp9 libvpx encoder failures with older library versions
  * fix 'xpra top' errors when the version string is missing
  * fix server errors when non interactive clients are connected
    (ie: 'xpra top')
  * fix http server error on incomplete installations
  * fix http server builtin script handler
  * fix icon loading errors causing empty start menus
  * fix compilation against ffmpeg 4.4 and later on some
    distributions
  * exit more quickly with a failure if the VFB failed to start
  * correctly replace existing notifications with the gtk
    notifier backend
  * silence some rare errors and stacktraces
  * support CUDA 11.3
- Update uglify-js to 3.13.4
* Tue Apr  6 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 4.1.2
  * fix unnecessary screen update delays
  * fix screen refresh rate detection
  * increase the default screen update refresh rate
  * fix missing encodings with 'upgrade' and 'upgrade-desktop'
    subcommands
  * fix client failures due to missing socket directories
  * more correct API usage of 'notify2' backend
  * fix `run_scaled` script handling of multiple arguments
  * fix ioctl error with nested SSH connections
  * fix video region detection error
  * fix sessions GUI not updating on process exit
  * fix compatibility with newer versions of python-zeroconf
  * fix directory listing with the builtin http server (still
    disabled by default)
  * fix the server's GetAll dbus property handler
  * fix display-name validation check
  * the 'exec-wrapper' option no longer needs to use an absolute
    path
  * ignore bell audio devices
  * show the correct list of pressed keys, unkown modifiers
  * prevent the splash screen process from consuming too much CPU
  * better service configuration file location detection
  * packaging script fixes, library and documentation updates
- Update xpra-html5 to 4.1.2 and uglify-js to 3.13.3
- Refresh xpra-paths.patch
* Wed Mar 17 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 4.1.1 (fixes boo#1182526)
  * ensure splash screen failures are not fatal, fix threading
    bug
  * avoid vaapi crashing in ffmpeg encoder
  * `xpra top` fixes:
    + correctly show the version number
    + laggy input handling and screen updates
    + long subcommand timeout
  * fix connection errors with trailing slash in display name
  * workaround API breakage in newer versions of python-zeroconf
  * warn just once if expected GStreamer element properties are
    missing
  * map more applications to text mode ('code', 'jetbrains')
  version 4.1:
  * Overhauled container based build system
  * Splash screen
  * `run_scaled` utility script
  Client:
  * header bar option for window control menu
  * generate a qrcode to connect
  * show all keyboard shortcuts
  * progress bar for file transfers
  * GTK cairo backend support for more native bit depths
  * disable xpra's keyboard shortcuts from the system tray menu
  * automatically include the server log in bug reports
  OpenGL client backend:
  * render at fixed bit depths with the `pixel-depth` option
  * support more bit depths
  Clipboard:
  * MacOS support for images, more text formats, etc
  * MS Windows support for images
  * wayland clients
  Server:
  * faster server startup
  * `xpra list-windows` subcommand
  * new window control commands: move - resize
  * remote logging: from server to client
  * support window re-stacking
  `xpra top`:
  * show pids, shortcuts
  * more details in the list view
  * show speed and quality
  Display:
  * bumped maximum resolution beyond 8K
  * set the initial resolution more easily using the
    'resize-display' option
  Encoding:
  * server side picture downscaling
  * libva hardware accelerated encoding
  * NVENC 30-bit accelerated encoding
  * vpx 30-bit
  * x264 30-bit
  * faster 30-bit RGB subsampling
  * scroll encoding now handled more generically
  * black and white mode
  Network:
  * IGD / UPNP
  * SO_KEEPALIVE option
  * clients can be queried using local sockets
  * specify connection attributes using the connection string
  * nested SSH tunnels
  * websocket header modules
  * specify the socket type with socket activation
  * expose the packet flush flag
  * `xpra shell` subcommand for interacting with processes in
    real time
  * custom group sockets directory permissions and name
  Testing:
  * better test coverage
  * cleanup output
- Refresh xpra-paths.patch
- Add xpra-html5 (now distributed separately) and uglify-js
  (required by the former) tarballs
- Spec cleanup
* Thu Feb 25 2021 Antonio Larrosa <alarrosa@suse.com>
- Require the pulseaudio-daemon capability instead of the
  pulseaudio package, so alternative implementations can be used
  (boo#1182730).
* Wed Feb 10 2021 olaf@aepfle.de
- Fix regex for /bin/bash
* Fri Feb  5 2021 olaf@aepfle.de
- Fix requires for /bin/bash
* Thu Dec 31 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 4.0.6
  * fix screen refresh performance issues, especially on jittery
    links
  * fix proxy instance control socket errors and process leak
  * fix slow subcommands due to unnecessary calls to ldconfig
  * fix server asynchronous packets getting delayed
  * fix 'xpra _proxy' zombies getting left behind (ssh mode)
  * fix failures to enable packet compression
  * fix connection errors when a non interactive client is
    already connected
  * fix ssh connection errors with proxycommand or proxyhost
    port numbers
  * fix timeouts with paramiko ssh client
  * fix ssh string escaping with MS Windows clients
  * fix client rejecting printing requests
  * fix duplicate / untimely audio-stop control packets with
    HTML5 client
  * fix console errors with Internet Explorer
  * fix capslock regression on MacOS and MSWindows shadow servers
  * fix errors accessing window handles on MS Windows (size
    hints, opengl, etc)
  * fix spurious refresh packets with mmap
  * fix mmap not used with some non-video areas
  * fix keyboard sub-layout detection with MS Windows clients
  * fix clipboard cleanup errors on MS Windows
  * fix clipboard with Wayland clients
  * fix window repaint with Wayland clients
  * fix printing diagnostic script
  * fix Python 3.9 compatibility
  * fix sysconfig path in systemd service file
  * fix xdg-open override script error handling
  * fix file-transfer failures with small files
  * fix file-transfers with non-ascii filenames
  * fix FIPS compatibility (no md5)
  * better file transfer message format
  * honour XPRA_XDG_EXPORT_ICONS=0 env var in all cases
  * hide passwords from authentication debug logging
  * make it possible to specify the socket type with systemd
    socket activation
  * re-add "~/.xpra" as socket-dir
  * typo in man page
- Refresh xpra-paths.patch
* Wed Nov 18 2020 aloisio@gmx.com
- Update to verison 4.0.5
  * fix caps lock wrongly applied to numeric keys
  * fix HTML5 client keyboard layout detection with Internet
    Explorer
  * fix HTML5 audio forwarding with some versions of Safari
  * fix HTML5 (un)fullscreen
  * fix ssl server hostname verification errors
  * fix syntax errors when using connections using nested ssh
    tunnels
  * fix socket_util import errors with some subcommands
  * fix http / websocket and ssl socket upgrade failures
  * fix server errors when ws sockets cannot be upgrade to wss
  * fix ssh command option not being honourd with the client
    launcher
  * fix proxy control socket becoming unresponsive after errors
  * fix proxy shutdown
  * fix proxy instance zombies on server start failures
  * fix sqlite authentication module not handling configuration
    options
  * fix stdout errors causing server startup or shutdown problems
  * fix Wayland detection and workarounds
  * fix clipboard errors under Wayland
  * fix client signal listener not forwarding signal messages
  * fix client failing to connect due to keymap changes (ie:
    Wayland)
  * fix client not showing authentication prompt only once per
    connection
  * fix opengl debug option for saving buffers as jpeg
  * fix spurious "missing resolution" errors (often with HTML5
    client resizing)
  * fix duplicated data in bug reports
  * fix download checksum verification (was not verified with
    python3 builds)
  * fix spurious file transfer errors with python3 builds
  * fix NVENC session leak due to flushing errors, support
    building with SDK10
  * remove "numpy" dependency for builds without NVENC / NVFBC
  * add new NVENC presets from SDK v10, workaround deprecation
    warnings
  * HTML5 connect page can now specify the display to connect to
  * avoid starting new threads for file transfers that don't
    need one
  * raise default maximum packet size to prevent connection
    errors with large xdg menu data
  * don't let bad http requests mess up the server log
  * prevent peek data or exception message from corrupting the
    log / stdout
  * remove dependency on "requests" package introduced in 4.0.4
  * make it possible to override the Xorg binary path detection
* Sun Sep 27 2020 aloisio@gmx.com
- Update to version 4.0.4
  * fix memory leak with 'scroll' encoding
  * fix NVENC encoder (profile errors)
  * fix unmanaged X11 message call which could cause GTK to
    crash when it fails
  * fix missing auto-refresh leaving a blurry image
  * fix incomplete repaints when window contents have padding
  * fix missing pixels on the edge of video areas in 'auto'
    encoding mode
  * fix connection errors with notifications disabled on the
    server
  * fix 'sync-xvfb' option: setup error, non-standard bit depth
    support
  * fix shadow server dbus SetRefreshDelay causing all further
    "xpra info" requests to fail
  * fix incomplete data in initial packets from shadow servers
  * fix error in dbus debug logging
  * fix client invalid list of encodings
  * fix workspace spurious warnings on 64-bit X11 systems
  * fix named-pipe server clash
  * fix syntax error in HTML5 client maximize toggle
  * fix keysym mapping with Xkb and some specific configurations
  * fix right click on systray using the gtk StatusIcon
    implementation
  * fix small file transfers not showing as completed
  * fix file-transfer UI for download vs download-and-open not
    being honoured
  * fix file-transfer identifiers getting lost
  * fix websocket compatibility with some client / middleware
  * fix missing windows due to an error in the named window icon
    handling
  * fix hard to trigger mmap memory leak
  * add support for sm86 architecture with CUDA 11.1
  * allow 'pager' source indication value to activate window
    server-side
  * workaround corruption on some windows when maximized
  * workaround more pyxdg bugs
  * make OpenGL probe timeout configurable
* Mon Sep  7 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Fixes for %%_libexecdir changing to /usr/libexec (bsc#1174075)
* Wed Aug 19 2020 Luigi Baldoni <aloisio@gmx.com>
- Use proper location of bash in script shebang
- Add runtime requirement
* Wed Aug 19 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%{_udevrulesdir} consistently throughout the .spec.
* Sat Aug  8 2020 aloisio@gmx.com
- Update to version 4.0.3
  * fix server crash caused by use after free in scrolling code
  * fix encryption option overzealously enforced on all socket
    types
  * fix network layer compression errors that can cause
    connections to drop
  * fix printing errors with some shell character encodings
  * fix NVENC h264 stream compatibility with HTML5 client
  * fix windows not getting focused when clicking on title bar
    (HTML5)
  * fix suspend / resume errors with tray windows
  * fix garbled terminal when ssh messages and 'top' client
    conflict
  * fix OpenGL force-enable option not honoured
  * fix tray geometry errors
  * fix socket setup error handler
  * fix minimum video scaling not being honoured via heuristics
  * fix error in main thread verifier (fortunately, never fired)
  * fix archlinux build root stripping
  * fix detection of named-pipe creation errors
  * fix clipboard data sometimes going missing when ownership
    changes
  * fix memory contents of the swscale pixel format object
  * fix csc_swscale converter getting recycled every time
  * fix division by zero errors during window cleanup
  * fix rfb connections missing all screen updates
  * fix toolbox examples when running under wayland
  * fix notification widget wrongly stealing input focus
  * fix support for building with CUDA 11.0
  * fix unshrinkable session-info window
  * fix window resizing errors when non-GUI clients are also
    connected
  * avoid ever using b-frames for text content
  * avoid opengl warning with wayland
  * add extra environment variables to try to disable any server
    side scaling
  * also update mdns records when the session name changes
  * workaround for older versions of python-cryptography
  * use 'text' mode for 'geany' (fixes lossy screen updates)
  * ensure all toolbox windows set a correct and readable window
    title
  * make it possible to specify the path used for saving video
    streams / frames
* Fri Jul 17 2020 Markus Ebner <info@ebner-markus.de>
- add python3-opengl, and python3-opengl-accelerate as recommended
  dependencies, to support OpenGL in the client
* Fri Jun  5 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 4.0.2
  * fix encryption not honoured with TCP sockets upgraded to
    WebSocket
  * fix xpra top client refresh rate via timer
  * fix opengl client info format shown in 'xpra top'
  * fix format of attributes given to glXChooseVisual
  * fix crashes in OpenGL context setup on X11
  * fix race condition in window statistics
  * fix server errors when non-interactive clients are connected
  * fix tray toolbox app
  * fix X11 server key symbol lookup via Xkb
  * html5 fixes:
    + fix missing desktop background
    + client errors painting rgb32 data with a padded rowstride
    + clipboard wrongly clearing data on failures
    + compatibility issues with Internet Explorer
    + missing transparency for windows in focus
    + no windows focused after close
    + connection errors caused by spurious packets
    + error in invalid packet handler
    + AES encrypted connections
    + connection errors with AES and lz4 (disable lz4 for now)
    + packet error with very small paint packets
    + 'insecure passwords' option shown in the wrong cases
    + handle window iconification messages
    + update version in about page
  * fix connection errors with 'None' values in bencoder (ie:
    html5)
  * fix connection errors with websocket connections and AES
    encryption
  * fix duplicate clipboard token sent with MS Windows servers
  * fix window initialization errors causing server startup
    failures
  * remove invalid extra strings from mdns service name
  * workaround bugs in pyxdg / menu configuration
  * add 'terminator' to the 'text' application hint
  * more explicit error message when trying to use python2
* Sun May 17 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 4.0.1
  * fix missing content-type for some windows
  * fix GTK server crash on exit
  * fix compatibility with newer versions of uglifyjs
  * fix ssh session start and attach on Posix systems
  * fix 'xpra send-file' to use absolute file paths
  * fix MacOS shadow servers failing to accept connections
* Sun May 10 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 4.0
  * Drop support for:
    + Python 2, GTK2
    + legacy versions (pre 1.0)
    + weak authentication
  * Network, per socket options:
    + authentication and encryption
    + ssl
    + ssh
    + bind options for client
  * make it easier to send files from the server
  * xpra toolbox subcommand
  * xpra help subcommand
  * xpra top new features
  * faster startup
  * signal handling fixes
  * smoother window resizing
  * refactoring and testing
    + unit tests coverage and fixes
    + completely skip loading unused features at runtime
    + get rid of capabilities data after parsing it
    + better module dependency separation
    + don't convert to a string before we need it
  * more useful window and tray title
  * make it easier to source environment
  * disable desktop animations in desktop mode
  * automatic start-or-upgrade, automatic X11 display rescue
  * support MS Windows OpenSSH server to start shadow
  * more selective use of OpenGL acceleration in client
  * expose server OpenGL capabilities
  * cleaner HTML5 syntax
- Refresh xpra-paths.patch
* Tue Apr 14 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 3.0.9
  * fix HTML5 client XSS
  * fix focus issues
  * fix server hangs and unpainted windows due to invalid
    dimensions
  * fix window icons and cursors visual corruption or crashes
  * fix unbearably slow screen updates when vrefresh value is
    invalid
  * fix client OpenGL crashes with remote starts (run probe
    first)
  * fix keypad regression (AltGr changes, again)
  * fix MS Windows shadow servers
  * fix race condition collecting latency data for session info
  * fix missing pycuda dependency for nvenc on MS Windows
  * fix missing signatures on MS Windows EXE and MSI builds
  * fix scoring of NVENC codec (should be used ahead of sofware
    encoders)
  * fix start menu updates getting lost
  * fix OpenGL diagnostic messages getting cut off
  * fix change of encoding from the system tray
  * fix quality and speed changes from the system tray
  * fix clipboard and popup menu problems with Eclipse
  * fix name of shadow server process on MS Windows, used in log
    file names
  * fix audio query subprocess with MS shadow servers
  * fix unlikely race condition in speaker forwarding shutdown
    sequence
  * fix desktop-fullscreen=yes automatic scaling
  * fix missing bug report data due to uninitialized X11 bindings
  * fix bug report error if we cannot grab a screenshot (ie:
    Wayland)
  * fix error saving binary data with python3 builds of the bug
    report tool
  * fix errors querying the display under Wayland
  * hide scary stacktraces when shutting down ssh proxy commands
  * if we have an ssh password we can use, try that first
  * blacklist VirtualBox's SVGA3D OpenGL driver (fixes black
    windows)
  * don't use webp with image dimensions beyond its limits
  * use regular X11 system tray with i3
  * hide confusing named-pipe prefix in empty output on MS
    Windows
  * HTML5 fixes: invalid IMG tag, reserved keyword, language
    detection, draw debugging, etc
  * don't try to read /proc if not on Posix
  * use a more specific python3 interpreter version
  * update application content-type mappings
  * remove out of date information from man page
* Tue Mar 31 2020 aloisio@gmx.com
- Update to version 3.0.8
  * fix handling of dpi command line switch (correctly this
    time?)
  * fix bug report window not getting focus on MacOS
  * fix spurious ssh key warnings with newer versions of paramiko
  * fix AltGr mode with non-X11 clients, layout-group changes
  * fix rare unexpected client exit on MS Windows
  * fix MS Windows clipboard:
    + update failures
    + convert CRLF line endings
  * Clipboard:
    + fix selection not shown as active in menus (MS Windows and
    MacOS)
    + fix spurious warnings when sharing a session
    + fix clipboard reset with python2 builds
    + selection translation for outbound data
    + support client applications that don't use TARGETS (ie:
    Motif)
    + reject invalid targets
  * fix 'xpra upgrade' wrongly updating non-xpra displays
  * fix logging error in client geometry debugging output
  * fix spurious de-iconifications
  * fix handling of server control commands with python3 clients
  * fix UDP backport bug sending control packets
  * fix vfb getting killed on upgrade failure
  * fix proxy server cleanup: force forwarders to terminate
  * fix session info errors during client exit
  * fix printer cleanup errors with invalid UTF8 printer names
  * fix transient-for popup window workaround
  * fix unicode errors saving xpra runner shell script with
    python3
  * better detection of Wayland environments
  * use python3 (if installed) by default on Ubuntu Xenial
  * don't use Xdummy on arm, too slow
  * don't show 'Download' button that we can't honour
  * show all pressed keys according to X11 server in 'xpra info'
  * try harder not to use video for tiny areas
* Sat Mar 14 2020 aloisio@gmx.com
- Update to version 3.0.7
  * fix avcodec2 race condition crash
  * fix errors when re-initializing windows (ie: toggling OpenGL
    on or off)
  * fix deiconification error when there are system trays
    forwarded
  * fix missing alpha channel when some windows are first shown
  * fix systemd-run errors: verify it does work before trying to
    use it
  * fix server crashes on SIGINT: shutdown cleanly
  * fix proxy server client connection setup error hanlder
  * fix file authentication handler using a default password
    filename
  * fix directshow errors on local mingw installations
  * fix opengl properties missing from server hello packet
  * fix HTML5 sound-control errors when speaker forwarding is
    disabled
  * fix HTML5 "Terminate" options wrongly enabled in "Connect"
    mode
  * fix clipboard sharing with the MacOS shadow server
  * fix MS Windows clipboard access denied errors
  * fix X11 clipboard error handling: continue processing
  * fix unit tests failures (clipboard, etc)
  * fix bug report clipboard copy and screnshots
  * fix clipboard timeouts when a client disconnects
  * fix mdns cleanup done twice on server exit, causing errors
  * fix malformed XSettings due to invalid color data format
  * fix HMAC hashes exposed, keep only valid options
  * fix 'showconfig' output for boolean values set to 'auto'
  * fix parsing of client display information in legacy format
  * fix validation of size-hints
  * fix cursor saving debug code with GTK3
  * fix keyboard layout group not getting reset on client exit
  * fix some empty keyboard layout group strings parsed as
    non-empty
  * fix keyboard-sync mode not being honoured by servers
  * fix keyboard raw mode
  * fix missing 'perispomeni' key mapping with Python 2 servers
  * add missing debug logging to keyboard mapping
  * more reliable lookup of keycodes when translating (non-X11
    clients)
  * skip bundling some external test modules with binary
    installers
  * avoid spurious background worker warnings on exit
  * make unavoidable comtypes error less scary
  * add 'libreoffice' to the text mode whitelist
  * packaging workarounds for setuptools breakage
* Mon Feb 10 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 3.0.6
  * fix UDP with Python3
  * fix key mapping issues with non-X11 clients and non-US
    layouts
  * fix notification logging errors during shutdown
  * fix window stacking order with html5 client and override
    redirect windows
  * fix png/P and png/L decoding
  * fix very slow startup on Debian due to missing
    libfakeXinerama
  * fix display scaling notification warning
  * fix errors generating the tray title string
  * fix missing webp modules in 'clean' build target
  * fix some special characters with HTML5 client
  * fix initiate-moveresize with multiple clients
  * fix control commands argument error handling
  * fix unit tests
  * fix window repaint issues: system tray, Python 2 non-opengl
    window spinners
  * fix server errors during client connection cleanup
  * fix spacebar and other characters with tablet input devices
    (ie: mobile browsers)
  * fix unhelpful backtraces when client application windows are
    lost
  * fix for crashes on X11 displays lacking RandR support
  * fix handling of non 24/32-bit png window icons
  * man page connection string fixes
  * disable cpuinfo module - known to cause problems on various
    platforms
  * ignore error and continue when loading version information
    from invalid builds
  * remove executable file permissions on files uploaded to the
    server
  * blacklist 'Intel(R) UHD Graphics 620'
  * use correct location for appdata.xml
  * use Debian location for systemd service config file
  * ensure emacs, gvim and xxdiff always use 'text' mode
  * re-enable pulseaudio memfd (was wrongly disabled in v3.0.0)
  * remove remnants of GTK2 dependencies from non-GTK2 components
  * add missing entry to path information tool
- Refreshed xpra-paths.patch
* Mon Feb  3 2020 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  shortcut through the -mini flavors.
* Tue Jan 28 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 3.0.5
  * fix fake Xinerama errors with unicode monitor names
  * fix av-sync backport for python2 servers
  * fix errors when the dbus submodule is not installed
  * fix RFB server key handling
  * fix exit code for unsupported sockets
  * fix tray title with openssh and plink SSH backends
  * fix 'xpra upgrade'
  * fix focus problems with OR windows
  * fix wrong client info shown in 'xpra top'
  * fix 'xpra top' error that scrambled the output, flickering
  * fix X11 keyboard query against secondary screens
  * skip trying to load X11 components on non-X11 platforms
  * allow F11 through to the browser to make it easier to go
    fullscreen
  * prevent sshfp dns errors from causing ssh connection failures
  * obscure passwords from log files
  * remove duplicated attribute from xpra info
  * remove unused loggers
  * expose av-sync and webcam client capabilities
  * better wayland mode detection
  * add more missing files to MANIFEST
  * add v4l2 codec files to clean target
  * add logging to gtk display cleanup
- Refreshed xpra-paths.patch to update systemctl location
* Mon Dec 23 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 3.0.4
  * fix av-sync
  * fix X11 property synchronization error due to race condition
  * fix XI2 bindings not loading
  * fix ssh upgrades wrongly claimed as supported when paramiko
    is not installed
  * fix 'wireless' network device detection on Linux
  * fix 'Sound Buffer' graph
  * fix errors caused by window title error handler
  * fix missing 'Packet Encoders' and 'Packet Compressors' with
    python3 clients
  * distinguish certificate verification errors from other ssl
    errors
- Enable ffmpeg encoder for Leap
* Wed Dec 11 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 3.0.3
  * fix clipboard synchronization with HTML5 client
  * fix window repaints with GTK3
  * fix GDK scaling causing window painting issues (force off)
  * fix slow repaint with OpenGL and combined updates (ie:
    scrolling)
  * fix missing video screen updates with 32-bit browsers:
    disable video
  * fix for X11 applications requesting invalid clipboard targets
  * fix "xpra top" errors when the terminal window is too small
  * fix blank xpra dialog windows when closed then shown again
    (ie: server commands)
  * fix compilation on non-i386 32-bit platforms
  * fix platform query errors causing command failures
  * fix Python2 builds: ignore GTK2 deprecation warnings
  * fix X11 property synchronization with Python2 builds
  * fix XSetClassHint call with Python 3
  * fix window move + resize shortcut
  * fix ssh proxy options not preserved when loading session
    files
  * fix error and missing refresh after changing quality or
    speed settings
  * fix NVENC error when pynvml is not installed
  * fix NVENC temporary failure retry code path
  * fix DPI value from the command line with desktop-scaling
  * fix typo in man page
  * fix errors with some odd Python3 builds
    (subprocess.getoutput)
  * fix cursor packets missing encoding attribute
  * fix notification error handling the speaker forwarding error
    message
  * fix incorrect and unhelpful message on connection error
  * make it possible to disable colourspace synchronization
  * show mdns status in xpra info
  * support CUDA 10.2
* Wed Nov 20 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 3.0.2
  * fix clipboard synchronization issue with MS Windows clients
    properly
  * fix Pillow 6.x compatibility with MS Windows packaging
  * fix null bytes in X11 error text properly
  * fix Python 3 servers wrongly re-sending the 'screen'
    attribute
  * fix remote logging failures with some message formats
  * fix lost screen updates
  * fix GTK scaling causing window geometry issues
  * fix HTML5 clipboard data sent from polling events
  * fix CUDA device logging with multiple devices
  * fix 32-bit build errors on xxhash
  * fix RPM jpeg and libyuv dependencies
  * fix OpenGL window not refreshing with Python 3
  * fix OpenGL context held for too long
  * fix SSH connection errors when 'port' is specified in the
    ssh config
  * fix faac and faad2 security issues in MS Windows and MacOS
    builds
  * fix window size hints misapplied with GTK3 on MS Windows and
    Wayland
  * disable OpenGL acceleration on old Intel chipsets
  * disable OpenGL acceleration with GTK3 builds on MS Windows
    (for now, pending bug)
  * show python interpreter version on about dialog
  * re-instante ancient popup window workaround (was disabled by
    mistake)
  * don't use av-synchronization for text and picture content
    types
  * workaround Fedora packaging causing gratuitious conflicts
* Sun Nov  3 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 3.0.1
  * fix clipboard synchronization failures with MS Windows
    clients
  * fix window cleanup errors preventing a clean exit
  * fix launcher error if sharing flag is unset
  * fix window states wrongly getting reset
  * fix SSH password dialog lockups on MS Windows
  * fix authentication module errors (multifile, python3)
  * fix radio buttons on start server dialog (python3)
  * fix error in encoding selection fallback (python3)
  * fix logging error in cups printing backend (python3)
  * fix null bytes in X11 error text (notifications errors)
  * fix keyboard debug logging error
  * fix error querying X11 properties under pure wayland client
  * fix unresponsive appindicator system tray
  * fix GDK window scaling setting wrongly propagated to the
    server
  * fix compilation on Ubuntu Eoan Ermine
  * fix file download failures on MS Windows due to invalid
    characters
  * fix handling of file download errors
  * fix Debian bin path warnings
  * fix error handling in 'xpra top'
  * fix pyobjc API compatibility in OpenGL transparency shim
  * fix out of date PKG OS version requirements
  * fix PKG compatibility with MacOS 10.15 Catalina
  * fix window border color parsing failures causing errors
  * fix OpenGL window paint errors with some drivers
  * make it easier to launch test tools
  * update Python to 3.7.5 on MacOS
  * bump revision to override broken Fedora packaging
  * show Python version in MacOS packages
  * re-enable tooltips on MS Windows
  * update to xxhash 0.7.2
  * consistent use of quotes in endpoint logging
- Spec cleanup
* Wed Oct  2 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 3.0
  * Python 3 port complete, now the default: #1571, #2195
  * much nicer HTML5 client user interface: #2269
  * Window handling:
    + smoother window resizing: #478 (OpenGL)
    + honouring gravity: #2217
    + lock them in readonly mode: #2137
  * xpra top subcommand: #2348
  * faster startup:
    + #2347 faster client startup
    + #2341 faster server startup
  * OpenGL:
    + more reliable driver probing: #2204
    + cursor paint support: #1497
    + transparency on MacOS: #1794
  * Encoding:
    + lossless window scrolling: #1320
    + scrolling acceleration for non-OpenGL backends: #2295
    + harden image parsing: #2279
    + workaround slow video encoder initialization (ie: NVENC)
    using replacement frames: #2048
    + avoid loading codecs we don't need: #2344
    + skip some CUDA devices, speedup enumeration: #2415
  * Clipboard:
    + new native clipboard implementations for all platforms:
    [#812]
    + HTML5 asynchronous clipboard: #1844
    + HTML5 support for copying images: #2312 (with watermarking)
    + brotli compression for text data: #2289
  * Authentication:
    + modular client authentication handlers: #1796
    + mysql authentication module: #2287
    + generic SQL authentication module: #2288
  * Network:
    + client listen mode: #1022
    + retry to connect until it succeeds or times out: #2346
    + mdns TXT attributes updated at runtime: #2187
    + zeroconf fixes: #2317
    + drop pybonjour: #2297
    + paramiko honours IdentityFile: #2282, handles SIGINT
    better: #2378
    + proxy server fixes for ssl and ssh sockets: #2399, remove
    spurious options: #2193
    + proxy ping and timeouts: #2408
    + proxy dynamic authentication: #2261
  * Automated Testing:
    + test HTML5 client: #2231
    + many new mixin tests: #1773 (and bugs found)
  * start-new-commands is now enabled by default: #2278, and the
    UI allows free text: #2221
  * basic support for native GTK wayland client: #2243
  * forward custom X11 properties: #2311
  * xpra launcher visual feedback during connection: #1421,
    sharing option: #2115
  * "Window" menu on MacOS: #1808
- Refreshed xpra-paths.patch
- Switched build to python 3
* Sat Jul 27 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.5.3
  * fix HTML5 MSIE 11 detection
  * fix HTML5 path of audio script for IE
  * fix HTML5 CapsLock and NumLock state detection
  * fix HTML5 desktop server screen size not resizing to match
    window
  * fix shadow servers display resizing not being propagated
  * fix scroll encoding with multi monitor shadow servers
  * fix handling of uncompressed window icon pixel data
  * fix handling of unicode values for desktop names
  * fix remote ssh failures with python3-only installations
  * fix '_monitor' subcommand with python3 clients
  * fix client ping latency calculations
  * fix non-strict ssl host key not honoured with wss connections
  * fix handling of websocket and ssl traffic with unix-domain
    sockets
  * fix ssl and websocket connection upgrades with python3
    servers
  * fix handling of websocket ping packets
  * fix unnecessary delay in initial connection handling
  * fix incorrect disconnections with non-UI clients
  * fix spurious socket warnings
  * fix distro information shown for proxied connections
  * fix invalid mdns records for rfb connections (desktop and
    shadow servers)
  * fix GTK3 signal handling before the main loop is running
  * fix file descriptor leak when running child commands
  * fix clipboard-direction setting not propagated to the client
  * fix clipboard datatype shortcut not taken due to a typo
  * fix clipboard bugs with python3 builds, invalid atoms
  * fix overzealous cleanup code in X11 root property handler
  * fix Xresources debug logging and error handler
  * fix errors during cleanup: close display later
  * fix uinput device mode with python3 servers
  * fix errors if md5 is not available: use sha1
  * fix default build options for RedHat
  * fix typos in man page and docstrings
  * silence annoying atk warnings
  * avoid running invalid lpinfo commands
  * improve compatibility with 'xpra top'
  * make it possible to skip opengl probing during server startup
  * add missing modal-window entry in man page
  * reduce weak RPM dependencies on gnome components
* Fri Jun 14 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.5.2
  * fix mmap leak which can cause the client to stop painting
  * fix OpenGL crashes: don't try to use it when probing process
    has crashed
  * fix errors in avahi error handler
  * fix connection errors when loading ssh public keys
  * fix tests being run with the wrong python interpreter version
  * fix systemd-run using the wrong python interpreter version
  * fix start menu with python3 clients
  * fix x264 encoder failing to create a compatible stream for
    the html5 client
  * fix unnecessary xdg menu data in some subcommands
  * fix large xdg menu data causing initial packet size errors
  * fix packet size warning message format
  * fix start menu with python3 clients
  * fix html5 client connection error when xdg-menu data is
    missing
  * fix html5 client compatibility with buggy x264 encoders (as
    above)
  * fix html5 client clipboard packet format
  * fix session info graphs start values
  * fix colour channels swapped with some window icons and
    desktop servers
  * fix slower compression code path wrongly used when av-sync
    is disabled
  * fix icon type attribute (remove dot)
  * fix signal forwarding with python3 servers
  * fix system tray forwarding with python3 servers
  * fix socket attributes name lookup for xpra info
  * fix handling proxy server info requests
  * fix proxy server info errors trying to enumerate sessions
  * fix automatic MTU adjustements with UDP transport
  * fix NVENC compatiblity with library soname found in newer
    installers
  * fix invalid python2 DEB dependency in main meta package
  * fix default config value for opengl attribute
  * fix HTML5 client authentication issue when going through a
    proxy server
  * fix socket errors on startup with bind-ssl
  * fix server dbus service attribute accessor methods
  * fix network jitter injector
  * fix avahi mdns publisher test tool
  * fix zeroconf error when service info is not available
  * fix remote ssh failures with python3-only installations
  * fix automatic interpreter version switching when re-executing
  * fix start-via-proxy exit code handler
  * fix socket-permissions option not being honoured
  * fix error in the codec loader if the first codec attempted
    fails
  * fix error in the codec instantiation leak detection code
  * fix exit hooks not being called with 'exit-with-client'
  * fix RandR build errors with older versions of Cython (ie:
    Xenial)
  * fix GTK3 build of the keyboard test tool on MS Windows
  * fix errors parsing xresources
  * fix handling of xsettings with python3 servers
  * fix font hinting detection with python3
  * fix errors during cleanup if server initialization or
    startup had failed
  * fix pure python3 builds cairo headers used
  * updated package dependencies: recommend python-dns for sshfp
    support
* Fri Apr 26 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.5.1
  * fix sending of icons as premultipled ARGB
  * fix compatibility with old versions of python-pillow
  * fix scroll encoding code flow (should be impossible to hit)
  * fix handling of info requests with Python3 servers
  * fix missing option for lock argument in man page
  * fix ssh errors handling authentication failures
  * fix ssh server connections and support 'none' authentication
  * fix start new command menu
  * fix appindicator failures when we fail to locate the default
    icon
  * fix command line tools usage under cygwin and terminal
    emulators
  * fix pointer position on multi-monitor shadow servers
  * fix system tray forwarding with python3 servers
  * fix window icons forwarding (MS Windows and MacOS mostly)
  * fix detection of splash window types
  * fix server startup errors when X11 root properties are
    invalid
  * fix shadow server startup failures on MacOS
  * fix system tray errors during shadow server startup on MacOS
  * fix printing errors with python3 builds and rencode packet
    encoder
  * fix parsing of printer options
  * fix dispatching of printer jobs to clients with python3
    servers
  * fix parsing of key symbol definitions with python3 servers
  * fix compatibility with older versions of GTK3
  * fix proxy video encoders initialization
  * fix 'missing encodings' server error with python3
  * fix spurious clipboard warning when clipboard is disabled
  * disable modal windows by default (was enabled by default
    since v2.3)
  * workaround buggy system trays
  * try harder to prevent hash collisions in scroll encoding
  * skip risky opengl probing when the initial check failed
  * prevent file conflicts with older packages
  * don't use appindicator with Fedora Gnome
  * minor packaging fixes (dates)
  * remove spurious ssh dnssec check logging
  * bump version in cups backend
* Tue Mar 26 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.5
  * Python 3 port mostly complete
  * pixel compression and bandwidth management:
    + better recovery from network congestion
    + distinguish refresh from normal updates
    + better tuning for mmap connections
    + heuristics improvements
    + use video encoders more aggressively
    + prevent too many delayed frames with x264
    + better video region detection with opengl content
  * better automatic tuning for client applications
    + based on application categories
    + application supplied hints
    + application window encoding hints
    + using environment variables and disabling video
  * HTML5 client improvements
  * Client improvements:
    + make it easier to start new commands, provide start menu
    + probe OpenGL in a subprocess to detect and workaround
    driver crashes
    + use appindicator if available
  * Server improvements:
    + start command on last client exit
    + honour minimum window size
    + Python 3
    + upgrade-desktop subcommand
  * Network layer:
    + less copying
    + use our own websocket layer
    + make mmap group configurable
    + TCP CORK support on Linux
  * SSH transport:
    + support .ssh/config with paramiko backend
    + connecting via ssh proxy hosts
  * SSHFP with paramiko:
    + clipboard: restrict clipboard data transfers size
  * code cleanups, etc
- Removed python2-opengl requirement (package not available
  and unnecessary since this release)
- Refreshed xpra-paths.patch
* Fri Mar  1 2019 Luigi Baldoni <aloisio@gmx.com>
- Enabled OpenGL (fixes boo#1127415)
- Added brotli as build requirement
- Refreshed xpra-paths.patch
* Thu Jan 31 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.4.3
  * fix minor glib timer handle leak and unnecessary timer
    scheduling
  * fix keyboard backwards compatibility with older 1.0 servers
  * fix error in keyboard debug logging
  * fix h264 decoding in HTML5 client
  * fix session info and bug report windows not getting
    dismissed in HTML5 client
  * fix precise wheel motion events with HTML5 client
  * fix clipboard with MacOS GTK2 clients
  * fix swap-keys menu entry wrongly disabled
  * fix potential memory leaks and errors in codecs due to cast
    error
  * fix crashy codecs on MS Windows: disable x264, 32-bit vpx
    with large sizes
  * fix validation errors with some quality and speed control
    commands
  * fix buggy parsing of clipboard-contents packets
  * fix jpeg encoder and decoder library version requirements
    (ie: for CentOS 7.x)
  * fix starting sessions via ssh on Ubuntu (workaround buggy
    systemd-run)
  * fix MS Windows clients handling system tray icons without an
    alpha channel
  * fix error in video exception message formating
  * fix errors handling pointer events with extra relative
    pointer data
  * fix potential string substitution errors with python2
  * fix connection to hosts that resolve to ipv6 only addresses
  * fix dbus mixin attributes initialized twice (wrong values)
  * fix race condition error with network congestion events
  * fix compatibility with newer ArchLinux Xorg path
  * fix exec-auth module timeout not being honoured
  * fix exec-auth wrongly returning success on MacOS
  * workaround SSH errors with Windows Services for Linux
  * reduce impact of fullscreen and maxmimized attributes on
    window refresh rate
  * never lock the batch delay when mmap is enabled
* Wed Dec  5 2018 aloisio@gmx.com
- Update to version 2.4.2
  * fix server crash with application setting invalid X11 atoms
  * fix missing windows with some mono applications (ignore
    invalid X11 atoms)
  * fix small X11 memory leak
  * fix encoding of empty areas (hard to trigger)
  * fix client hangs due to signal-watcher (now disabled with
    python2)
  * fix virtual printer cleanup errors
  * fix leaking xvfb processes when displayfd times out
  * fix window size hints not being sanitized correctly
  * fix cpu waste and automatic quality calculations
  * fix statistics used by shadow servers
  * fix error capturing screenshots on MS Windows
  * fix logging error in modifier state change failure code path
  * fix nvenc errors with odd image heights
  * fix over aggressive screen update rectangle merging
  * fix race condition causing the connection cleanup code to
    run twice
  * fix ssh dialog button actions
  * ensure Qt applications use the X11 backend so we can
    intercept them
  * skip unnecessary video tests when mmap is enabled
  * handle property change handlers errors more gracefully
  * avoid recycling video contexts unnecessarily
  * don't flush video encoders when doing a regular content
    refresh
* Sun Nov  4 2018 Jan Engelhardt <jengelh@inai.de>
- Make xpra-html5 subpackage noarch
- Speed up find -exec
* Sun Nov  4 2018 Luigi Baldoni <aloisio@gmx.com>
- Dropped xpra-rpmlintrc
* Thu Nov  1 2018 aloisio@gmx.com
- Update to version 2.4.1
  * fix popup window focus for some Java applications
  * fix popup window focus issue (ie: xterm menu)
  * fix system tray errors when mmap is disabled
  * fix missing codecs (numpy was blocked from loading)
  * fix nvenc compatibility with more python / cython / OS
    versions
  * fix backwards compatibility in keyboard mapping
  * fix session info errors when connecting to older servers
  * fix man page typo
  * fix default value 'auto' for ssh option, better compatibility
  * fix dead code triggering some debug warnings
  * fix rare race condition when closing a connection
  * fix 'flush' client encoding options parsing
  * fix overzealous clipboard sanitization code
  * fix missing notification messages
  * fix ssh client authentication: try all keys found
  * fix version update check
  * fix usability issues with GTK3, especially on MS Windows
  * fix cython compilation warnings
  * avoid ethtool warning spam
  * use correct headers for building python3 cairo workaround
    module
* Tue Oct 30 2018 Luigi Baldoni <aloisio@gmx.com>
- Added python2-paramiko as recommended runtime dependency
- Spec cleanup
* Fri Oct 26 2018 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.4
  * SSH client integration (paramiko)
  * builtin server support for TCP socket upgrades to SSH
    (paramiko)
  * automatic TCP port allocation
  * expose desktop-sessions as VNC via mdns
  * add zeroconf backend
  * register more URL schemes
  * window content type heuristics configuration
  * use content type it to better tune automatic encoding
    selection
  * automatic video scaling
  * bandwidth-limit management in video encoders
  * HTML5 client mpeg1 and h264 decoding
  * HTML5 client support for forwarding of URL open requests
  * HTML5 client Internet Explorer 11 compatibility
  * HTML5 client toolbar improvements
  * HTML5 fullscreen mode support
  * limit video dimensions to cap CPU and bandwidth usage
  * keyboard layout handling fixes
  * better memory management and resource usage
  * new default GUI welcome screen
  * desktop file for starting shadow servers more easily
  * clipboard synchronization with multiple clients
  * use notifications bubbles for more important events
  * workarounds for running under Wayland with GTK3
  * modal windows enabled by default
  * support xdg base directory specification and socket file time
  * improved python3 support (still client only)
  * multi-window shadow servers on MacOS and MS Windows
  * buildbot upgrade
  * more reliable unit tests
  * fixes and workarounds for Java client applications
  * locally authenticated users can shutdown proxy servers
  * restrict potential privileged information leakage
  * enhanced per-client window filtering
  * remove extra pixel copy in opengl enabled client
  * clip pointer events to the actual window content size
  * new platforms: Ubuntu Cosmic, Fedora 29
- Refreshed xpra-paths.patch
- Spec cleanup
* Mon Oct  8 2018 aloisio@gmx.com
- Update to version 2.3.4
  * fix server does not shutdown cleanly (Xvfb not killed)
  * fix signals not emitted (ie: delay-tray command line option)
  * fix client desktop-scaling corner cases
  * fix handling of mixed clicks on system tray and the menu
    entries
  * fix MS Windows shadow server's cursor capture
  * fix URL parsing from launcher (ie: MacOS URL association)
  * fix MacOS crash with GTK3 builds and file chooser
  * fix non-opengl windows missing spinner with GTK3
  * fix RPM license information
  * fix mDNS zeroconf library version on MS Windows with Python 2
  * fix connection errors from making the client launcher exit
  * fix python3 errors in dbus server code
  * fix spurious error messages caused by video pipeline changes
  * fix proxy-video-encoders=all substitution
  * fix unicode string errors with RFB protocol and Python 3
  * fix missing idle and clipboard server information
  * fix .xpra file association with DEB packaging
  * fix pointer polling error with RFB connections (pointer
    going AWOL)
  * fix handling of closed RFB connections
  * fix unmanaged X11 call from shadow servers (potential
    crashes)
  * fix fallback pynotify notification handler
  * fix Python 3 shadow servers with RFB
  * fix Python 3 string errors writing run-xpra scripts
  * fix deadlocks with RFB connections
  * fix missing key mapping errors with RFB clients
  * fix session name not honoured or exposed via mdns for shadow
    servers
  * fix X11 display detection (socket may be owned by root with
    some display managers)
  * fix compatibility with csh and tcsh
  * fix spurious modifier key events from the HTML5 client
  * fix tray icon corruption on MS Windows
  * fix Motif WM hints parsing
  * fix DEB packaging dependencies
  * fix NVENC encoder wrongly exposing encodings which are not
    available
  * fix error running unit tests on MS Windows
  * fix potential file descriptor leak
  * fix valid XAuthority path potentially not found because
    unexpanded
  * fix proxy servers not honouring passwords in connection
    strings
  * fix sqlite authentication backend issue with identical
    usernames
  * support CUDA 10 and optimizations for Volta GPUs
  * Fedora 29 compatibility
  * fix race condition in unit tests which was causing random
    failures
  * add dependency required for running the unit tests with
    rpmbuild
  * prevent repeated clipboard warnings
  * let the server chooose the best initial quality to use
  * add file missing from clean build target
  * add missing entries in man page
  * add missing desktop file icons
  * shadow the current display if none is specified and we find
    more than one display
  * remove unneeded import, spurious debug logging
  * limit the amount of information exposed via the proxy
    server's dbus service
  * support base64 encoded SSL certificate data
  version 2.3.3
  * fix value shown in frame extents warning
  * fix HTML5 relative URLs for window control icons
  * fix HTML5 pointer events missing modifier keys
  * fix parsing errors when no display is specified
  * fix URL parsing with Python 3
  * fix tray setup errors on early client exit
  * fix putty plink PATH lookup issue
  * fix python3 compatibility for printer forwarding script
  * fix python3 alert box on MS Windows
  * fix python3 packaging on MS Windows
  * fix python3 client rendering of transparency with opengl
    disabled
  * fix file descriptor warnings on process exit with MS Windows
    builds
  * fix MS Windows monitor API overflow on 64-bit systems
  * fix compilation error with latest MSYS2 installations
  * fix desktop servers exit code
  * fix network congestion calculations when records expire
  * fix bandwidth warnings caused by slow client picture decoding
  * fix xpra info race condition error during cleanup
  * fix clipboard warnings: don't enable it unless the client
    requests it
  * fix spurious stacktraces caused by focus events on OR windows
  * fix painting of spinners with desktop-scaling and non-opengl
    backends
  * fix 'terminate server when command exits' from html5 client
  * fix SSL socket timeouts in proxy server
  * fix errors starting proxy instances if the user's home
    directory does not exist
  * fix ssh start remote command line compatibility mode
  * fix command line backwards compatibility
  * fix handling of tray geometry and keyboard detection failures
  * fix bandwidth-limit changes from the system tray menu
  * fix system version warnings on MacOS
  * force GTK3 Posix clients to use X11 backend (native Wayland
    crashes)
  * support cx_Freeze 5.x on MS Windows
  * don't require local user accounts with pam logins
  * drop invalid client connections without showing errors
    (desktop mode)
  * support building with Python 3.7 (some features made
    optional until ported over)
  * disable webcam forwarding with MS Windows client (broken
    upstream)
  * add missing RPM dependencies for running unit tests
  * prevent Python Pillow debug log spam
  * don't show spurious import errors during printing subsystem
    cleanup
  * show another possible reason for connection failures
  * make remote ssh command easier to parse
  * abort tests if build fails
  * use free colour profiles in all icon files
  * add missing man page entry for 'forward-xdg-open'
  * add missing files to manifest
  * man page typos
* Tue Jul 31 2018 jon@moozaad.co.uk
- added libsystemd build req to fix invalid /etc/default/xpra usage
* Wed Jul 18 2018 jon@moozaad.co.uk
- re-added xdummy args as auto detection wasn't enabling it
- reverted to python 2 for server support
- removed python 3 specific patch (cairo)
* Wed Jul 18 2018 jon@moozaad.co.uk
- switched to python3
- added webp support
- cleanup spec file of default build options
- now builds on Leap >= 42
- patched broken py3cairo detection
- Removed ffmpeg for <= Leap 15 (requires libav >= 58.18)
- Removed vpx for < Leap 15 (that leaves Leap 42.x with avcodec2 and webp)
* Wed Jul 18 2018 aloisio@gmx.com
- Update to version 2.3.2
  * fix notification actions support with shadow servers
  * fix paint errors with reformatted images using outdated
    stride value
  * fix control commands that call window refresh
  * fix broken pipe error when the browser cancels downloading
    the noicon placeholder
  * fix spurious refresh events
  * fix missing bug report data due to path errors
  * fix XAUTHORITY environment variable getting clobbered
  * fix html5 window refresh not throttled when the document is
    not visible
  * fix non-opengl painting of windows with a padding area
  * fix rgb paint of mmap data with the python2 cairo backend
  * fix invalid clipboard toggle requests not ignored
  * fix missing context handler for keymap setup (crash possible)
  * fix proxy server test to use a signal to stop the test
    instance
  * fix invalid exception value in X11 atom bindings
  * fix bandwidth limit client bypass and connection errors
  * fix building CUDA kernels with GCC 8.1
  * fix tray menu setup error when the clipboard is disabled
  * fix GTK3 buffer overflow with non-opengl backend
  * fix startup errors with pulseaudio if XDG_RUNTIME_DIR is
    missing
  * fix clipboard token send error when there are no targets
  * don't overwrite the dynamic system tray icon with the
    default one on startup
  * correctly disable desktop-scaling when mmap is enabled
  * skip repainting pointer overlay when the position is
    unchanged
  * prevent authenticated users from shutting down proxy servers
  * don't turn off notifications when we don't have a forwarder
    instance
  * don't try to log an exception that does not exist
  * allow the user to disable all video encoders and csc modules
  * send missing exception details to server with remote-logging
  * avoid RFB errors if screen capture fails
  * avoid further errors when shadow capture fails
  * recommend the dbus-x11 with the DEB package
  version 2.3.1:
  * fix CentOS / RHEL rpm dependencies for ldap authentication
  * fix spurious notifications warning
  * fix unsynced X11 context access to DPI (potential crash or
    warnings)
  * fix compilation warning in ffmpeg compatibility shim
  * fix filename extension check in launcher
  * fix h264 decoding in html5 client
  * fix menu stacking level in html5 client
  * fix focus issues with html5 client
  * fix socket error race condition during shutdown
  * fix scroll encoding errors on images with modified rowstride
  * fix desktop and shadow servers xinerama sizing issues
  * fix pixel encoding errors at low pixel depths
  * fix pixel-depth 8 wrongly rejected for start-desktop mode
  * fix colour encoding at pixel-depth 8
  * fix systemd warnings and packaging on Ubuntu 16.04
  * fix html5 client errors with audio debugging enabled
  * fix readonly mode bypass
  * fix client failure on servers without a valid desktop size
  * fix VNC connection handling of authentication
  * fix scary X11 desktop server warning with VNC clients
  * fix error in video debug logging
  * fix nvfbc errors during cleanup after initialization failures
  * fix client launcher not exiting on close
  * fix RFB clients causing sessions to be locked
  * fix rare deadlocks in exception handler
  * fix MacOS deprecation warnings
  * fix screen capture test script
  * fix CUDA DLL packaging
  * fix named-pipe errors with MS Windows Python3 and 64-bit
    builds
  * fix MinGW path detection issues
  * fix potential mmap leak with Python3 builds
  * fix screen update errors when XShm is disabled
  * silence GCC warnings when compiling NvFBC on MS Windows
  * increase default bandwidth congestion tolerance
  * remove duplicated DLLs from MS Windows Python3 builds
  * allow debugging via environment variables for all categories
  * don't prompt for the ssh password if we already have it
  * honour CFLAGS and LDFLAGS env vars
  * remove duplicated encoding from vpx encoder
  * add workaround for distributions shipping unpatched distutils
  * increase unit test failure timeout
  version 2.3:
  * stackable authentication modules
  * tcp wrappers authentication module
  * gss, kerberos, ldap and u2f authentication modules
  * request access to the session
  * pulseaudio server per session to prevent audio leaking
  * better network bandwidth utilization and congestion
    management
  * faster encoding and decoding: YUV for webp and jpeg, encoder
    hints, better vsync
  * notifications actions forwarding, custom icons, expose
    warnings
  * upload notification and management
  * shadow servers multi window mode
  * tighter client OS integratioin
  * client window positioning and multi-screen support
  * unique application icon used as tray icon
  * multi stop or attach
  * control start commands
  * forward signals sent to windows client side
  * forward requests to open URLs or files on the server side
  * html5 client improvements: top bar, debugging, etc
  * custom http headers, support content security policy
  * python3 port improvements
  * bug fixes: settings synchronization, macos keyboard mapping,
    etc
  * packaging: switch back to ffmpeg system libraries, support
    GTK3 on macos
  * structural improvements: refactoring, fewer synchronized X11
    calls, etc
  version 2.2:
  * support RFB clients (ie: VNC) with bind-rfb or rfb-upgrade
    options
  * UDP transport (experimental) with bind-udp and
    udp://host:port URLs
  * TCP sockets can be upgrade to Websockets and / or SSL, RFB
  * multiple bind options for all socket types supported: tcp,
    ssl, ws, wss, udp, rfb
  * bandwidth-limit option, support for very low bandwidth
    connections
  * detect network performance characteristics
  * "xpra sessions" browser tool for both mDNS and local sessions
  * support arbitrary resolutions with Xvfb (not with Xdummy yet)
  * new OpenGL backends, with support for GTK3 on most platforms
    and window transparency on MS Windows
  * optimized webp encoding, supported in HTML5 client
  * uinput virtual pointer device for supporting fine grained
    scrolling
  * connection strings now support the standard URI format
    protocol://host:port/
  * rencode is now used by default for the initial packet
  * skip sending audio packets when inactive
  * improved support for non-us keyboard layouts with non-X11
    clients
  * better modifier key support on Mac OS
  * clipboard support with GTK3
  * displayfd command line option
  * cosmetic system tray menu layout changes
  * dbus service for the system wide proxy server (stub)
  * move mmap file to $XDG_RUNTIME_DIR (where applicable)
  * password prompt dialog in client
  * fixed memory leaks
- Refreshed xpra-paths.patch
- Switched to ffmpeg4
* Fri Nov 10 2017 aloisio@gmx.com
- Update to version 2.1.3 (see NEWS)
- Refreshed xpra-paths.patch
* Wed Jul 26 2017 aloisio@gmx.com
- Update to version 2.1 (see NEWS)
* Tue Sep 22 2015 olaf@aepfle.de
- Use pkgconfig for ffmpeg BuildRequires
* Wed Nov 12 2014 olaf@aepfle.de
- avoid republish after rebuild of unchanged sources
* Thu May 30 2013 pascal.bleser@opensuse.org
- update to 0.9.4
* Tue Apr 24 2012 pascal.bleser@opensuse.org
- initial version (0.2.0)
